@@ -1,5 +1,4 @@
-/* $Id: irplib_framelist.c,v 1.30 2013/02/27 16:05:13 jtaylor Exp $
- *
+/* 
  * This file is part of the irplib package 
  * Copyright (C) 2002,2003 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: jtaylor $
- * $Date: 2013/02/27 16:05:13 $
- * $Revision: 1.30 $
- * $Name: sinfo-2_4_0 $
- */
-
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -37,7 +29,6 @@
 
 #include "irplib_framelist.h"
 #include "irplib_utils.h"
-#include <cpl.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -210,8 +201,6 @@ irplib_framelist * irplib_framelist_cast(const cpl_frameset * frameset)
 {
 
     irplib_framelist * self;
-    const cpl_frame * frame;
-    int i;
 
 
     cpl_ensure(frameset != NULL, CPL_ERROR_NULL_INPUT, NULL);
@@ -219,13 +208,16 @@ irplib_framelist * irplib_framelist_cast(const cpl_frameset * frameset)
     /* The function cannot fail now */
     self = irplib_framelist_new();
 
-    for (i = 0, frame = cpl_frameset_get_first_const(frameset);
-         frame != NULL;
-         i++, frame = cpl_frameset_get_next_const(frameset)) {
+    for (int i = 0; i < cpl_frameset_get_size(frameset); i++) 
+    {
+        const cpl_frame * frame = cpl_frameset_get_position_const(frameset, i);
 
         cpl_frame * copy = cpl_frame_duplicate(frame);
 
-        const cpl_error_code error = irplib_framelist_set(self, copy, i);
+#ifndef NDEBUG
+        const cpl_error_code error =
+#endif
+            irplib_framelist_set(self, copy, i);
 
         assert(error == CPL_ERROR_NONE);
 
@@ -252,16 +244,18 @@ cpl_frameset * irplib_frameset_cast(const irplib_framelist * self)
 {
 
     cpl_frameset * new;
-    int i;
 
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, NULL);
 
     /* The function cannot fail now */
     new = cpl_frameset_new();
 
-    for (i = 0; i < self->size; i++) {
+    for (int i = 0; i < self->size; i++) {
         cpl_frame * frame = cpl_frame_duplicate(self->frame[i]);
-        const cpl_error_code error = cpl_frameset_insert(new, frame);
+#ifndef NDEBUG
+        const cpl_error_code error =
+#endif
+            cpl_frameset_insert(new, frame);
 
         assert(error == CPL_ERROR_NONE);
 
@@ -305,20 +299,21 @@ irplib_framelist * irplib_framelist_extract(const irplib_framelist * self,
         const cpl_frame * frame = self->frame[i];
         const char * ftag = cpl_frame_get_tag(frame);
         cpl_frame * copy;
-        cpl_error_code error;
+        cpl_error_code code;
 
         if (ftag == NULL) {
             /* The frame is ill-formed */
             irplib_framelist_delete(new);
-            cpl_ensure(0, CPL_ERROR_ILLEGAL_INPUT, NULL);
+            (void)cpl_error_set(cpl_func, CPL_ERROR_ILLEGAL_INPUT);
+            return NULL;
         }
 
         if (strcmp(tag, ftag)) continue;
 
         copy = cpl_frame_duplicate(frame);
 
-        error = irplib_framelist_set(new, copy, newsize);
-        assert(error == CPL_ERROR_NONE);
+        code = irplib_framelist_set(new, copy, newsize);
+        if (code != CPL_ERROR_NONE) break; /* Should not be possible */
 
         if (self->propertylist[i] != NULL) new->propertylist[newsize]
             = cpl_propertylist_duplicate(self->propertylist[i]);
@@ -365,7 +360,7 @@ irplib_framelist * irplib_framelist_extract_regexp(const irplib_framelist* self,
     irplib_framelist * new;
     int error;
     int i, newsize;
-    const int xor = invert == CPL_FALSE ? 0 : 1;
+    const int xor_val = (invert == CPL_FALSE ? 0 : 1);
     regex_t re;
 
 
@@ -391,7 +386,7 @@ irplib_framelist * irplib_framelist_extract_regexp(const irplib_framelist* self,
         }
 
         if ((regexec(&re, tag, (size_t)0, NULL, 0) == REG_NOMATCH ? 1 : 0)
-            ^ xor) continue;
+            ^ xor_val) continue;
 
         copy = cpl_frame_duplicate(frame);
 
@@ -629,7 +624,7 @@ cpl_error_code irplib_framelist_load_propertylist(irplib_framelist * self,
   @param    invert Boolean to invert the sense of the pattern matching.
   @return   CPL_ERROR_NONE or the relevant CPL error code
   @see      irplib_framelist_load_propertylist()
-  @note     Use a regexp of "" to load all properties. If a frame already has
+  @note     Use a regexp of ".?" to load all properties. If a frame already has
             a propertylist, it is not modified (and no propertylist is loaded
             for that frame).
 
@@ -911,8 +906,8 @@ cpl_error_code irplib_framelist_contains(const irplib_framelist * self,
                                          cpl_boolean is_equal, double fp_tol)
 {
 
-    char * value_0;
-    char * value_i;
+    char * value_0 = NULL;
+    char * value_i = NULL;
     cpl_type type_0 = CPL_TYPE_INVALID;
     int i, ifirst = -1;  /* First non-NULL propertylist */
 
@@ -1068,7 +1063,7 @@ cpl_imagelist * irplib_imagelist_load_framelist(const irplib_framelist * self,
 
     for (i=0; i < self->size; i++, image = NULL) {
         const char * filename = cpl_frame_get_filename(self->frame[i]);
-        cpl_error_code error;
+        cpl_error_code code;
 
         if (filename == NULL) break;
 
@@ -1086,8 +1081,8 @@ cpl_imagelist * irplib_imagelist_load_framelist(const irplib_framelist * self,
             break;
         }
 
-        error = cpl_imagelist_set(list, image, i);
-        assert(error == CPL_ERROR_NONE);
+        code = cpl_imagelist_set(list, image, i);
+        if (code != CPL_ERROR_NONE) break; /* Should not be possible */
     }
 
     cpl_image_delete(image);
@@ -1095,7 +1090,7 @@ cpl_imagelist * irplib_imagelist_load_framelist(const irplib_framelist * self,
     if (cpl_imagelist_get_size(list) != self->size) {
         cpl_imagelist_delete(list);
         list = NULL;
-        assert(cpl_error_get_code() != CPL_ERROR_NONE);
+        (void)cpl_error_set_where(cpl_func);
     }
 
     return list;
@@ -1275,10 +1270,11 @@ static cpl_boolean irplib_property_equal(const cpl_propertylist * self,
     }
     default:
         /* Unknown property type */
+#ifdef NDEBUG
+        equal = CPL_FALSE;
+#endif
         assert( 0 );
 
-        equal = CPL_FALSE; /* In case of -DNDEBUG */
-
     }
 
     if (!equal) {
