@@ -76,7 +76,7 @@
 #include <sinfo_msg.h>
 #include <sinfo_error.h>
 #include <sinfo_utils_wrappers.h>
-
+#include <sinfo_pfits.h>
 
 
 /*-----------------------------------------------------------------------------
@@ -314,11 +314,41 @@ sinfo_rec_distortion(cpl_parameterlist *config, cpl_frameset *set)
     if(line_cor==1) {
         check_nomsg(sinfo_ima_line_cor(config,set));
     }
+    {/* special check in case of J band distortion data after 31/01/2018 */
 
-    //cknull_nomsg(set_fibre_ns=sinfo_frameset_extract(set,RAW_FIBRE_NS));
+    	cpl_frame* frm=cpl_frameset_find(set,"FIBRE_NS");
+    	const char* fname=cpl_frame_get_filename(frm);
+    	cpl_propertylist* plist=cpl_propertylist_load(fname,0);
+    	double mjd_obs=sinfo_pfits_get_mjdobs(plist);
+    	char band[FILE_NAME_SZ];
+    	sinfo_get_band(frm,band);
+    	//sinfo_msg("band=%s",band);
+    	//sinfo_msg("mjd_obs=%g",mjd_obs);
+    	if ( strcmp(band,"J") == 0 && mjd_obs > 58150.) {
+    		p = cpl_parameterlist_find(config, "sinfoni.bp_dist.min_cut");
+    		if (cpl_parameter_get_double(p) == cpl_parameter_get_default_double(p)) {
+    			sinfo_msg_warning("J band, data after 31/01/2018, use bp_dist-min_cut=0.05");
+    			cpl_parameter_set_double(p,0.05);
+    			cpl_parameter_set_default_double(p,0.05);
+
+    		}
+    	}
+    	cpl_propertylist_delete(plist);
+    }
+
+    set_fibre_ns=sinfo_frameset_extract(set,RAW_FIBRE_NS);
+    if (cpl_frameset_get_size(set_fibre_ns) < 75 ) {
+       	sinfo_msg_warning("For robustness it is strongly recommended to input 75 frames (if available) tagged as %s",RAW_FIBRE_NS);
+    }
     set_fibre_ns=cpl_frameset_duplicate(set);
-    cknull_nomsg(set_flat_ns=sinfo_frameset_extract(set,RAW_FLAT_NS));
+    set_flat_ns=sinfo_frameset_extract(set,RAW_FLAT_NS);
+    if (cpl_frameset_get_size(set_flat_ns) < 2 ) {
+    	sinfo_msg_warning("For robustness it is strongly recommended to input two frames tagged as %s one flat on one flat off",RAW_FLAT_NS);
+    }
     cknull_nomsg(set_wave_ns=sinfo_frameset_extract(set,RAW_WAVE_NS));
+    if (cpl_frameset_get_size(set_wave_ns) < 2 ) {
+        sinfo_msg_warning("For robustness it is strongly recommended to input two frames tagged as %s one arc lamp on one arc lamp off",RAW_WAVE_NS);
+    }
     check_nomsg(p=cpl_parameterlist_find(config,"sinfoni.bp.method"));
     check_nomsg(cpl_parameter_set_string(p,"Normal"));
     check_nomsg(raw_set=cpl_frameset_duplicate(set));
