@@ -66,6 +66,7 @@
 #include <sinfo_new_psf.h>
 #include <sinfo_key_names.h>
 #include <sinfo_raw_types.h>
+#include <sinfo_ref_types.h>
 #include <sinfo_functions.h>
 #include <sinfo_tpl_utils.h>
 #include <sinfo_tpl_dfs.h>
@@ -104,10 +105,23 @@ static char sinfo_rec_jitter_description2[] =
                 "A corresponding (band,preoptics) master bad pixel map with tag MASTER_BP_MAP\n"
                 "A corresponding (band,preoptics) slitlets position frame with tag SLIT_POS\n"
                 "A corresponding (band) distortion table with tag DISTORTION\n"
-                "A corresponding (band) slitlet distance table with tag SLITLETS_DISTANCE\n";
-
+                "A corresponding (band) slitlet distance table with tag SLITLETS_DISTANCE\n"
+                "Optional Input: \n";
 
 static char sinfo_rec_jitter_description3[] =
+                "FLUX_STD_CATALOG, the catalog of flux std stars \n"
+                "EXTCOEFF_TABLE, The Atmospheric Extinction correction table \n"
+                "EFFICIENCY_WINDOWS, the regions used to compute QC on efficiency  \n"
+		        "RESP_FIT_POINTS_CATALOG, the catalog indicating points to fit the response \n"
+		        "RESPONSE_WINDOWS, the regions used to compute QC on the response  \n"
+                "TEL_MOD_CATG, the Catalog of Telluric models \n"
+                "QUALITY_AREAS, the	areas where the quality of \n"
+                "the Telluric fitting is calculated\n"
+		        "FIT_AREAS, the	areas used for Telluric model fitting \n"
+                "HIGH_ABS_REGIONS, the High absorption regions\n";
+
+
+static char sinfo_rec_jitter_description4[] =
                 "The output is an image resulting from the IMA1 op IMA2 where op indicates\n"
                 "A reference table with the position of the first "
                 "column with tag FIRST_COLUMN\n"
@@ -120,7 +134,7 @@ static char sinfo_rec_jitter_description3[] =
                 "(PRO.CATG=BP_MAP_COADD_x_OBS x=STD,OBJ,PSF)\n"
                 "\n";
 
-static char sinfo_rec_jitter_description[1400];
+static char sinfo_rec_jitter_description[1800];
 
 /*-----------------------------------------------------------------------------
                                 Functions code
@@ -152,6 +166,7 @@ cpl_plugin_get_info(cpl_pluginlist *list)
     strcpy(sinfo_rec_jitter_description,sinfo_rec_jitter_description1);
     strcat(sinfo_rec_jitter_description,sinfo_rec_jitter_description2);
     strcat(sinfo_rec_jitter_description,sinfo_rec_jitter_description3);
+    strcat(sinfo_rec_jitter_description,sinfo_rec_jitter_description4);
 
     cpl_plugin_init(plugin,
                     CPL_PLUGIN_API,
@@ -286,8 +301,11 @@ static int sinfo_rec_jitter(cpl_parameterlist *config, cpl_frameset *set)
     cpl_parameter* p=NULL;
     int psf_sw=0;
     int std_sw=0;
-    cpl_frameset* ref_set=NULL;
+    cpl_frameset* tmp_set=NULL;
+    cpl_frameset* eff_set=NULL;
+    cpl_frameset* store_set=NULL;
     int line_cor=0;
+    int flat_ind=0;
 
     sinfo_msg("Welcome to SINFONI Pipeline release %d.%d.%d",
               SINFONI_MAJOR_VERSION,SINFONI_MINOR_VERSION,SINFONI_MICRO_VERSION);
@@ -303,69 +321,118 @@ static int sinfo_rec_jitter(cpl_parameterlist *config, cpl_frameset *set)
         check_nomsg(sinfo_ima_line_cor(config,set));
     }
 
-    check_nomsg(ref_set=cpl_frameset_duplicate(set));
-    /* ===============================================================
-     Defines several framesets each with a pair obj-sky,
-     stack each pair, put the results in set
-     =============================================================== */
-    ck0(sinfo_cub_stk_frames(config,&set,cpl_func,&pro_ctg_cube),
-        "Cannot stack RAW frames") ;
 
-    /* ===============================================================
-     SCI OBJNOD
-     =============================================================== */
-    sinfo_msg("------------------------------") ;
-    sinfo_msg("COADDING CUBES");
-    sinfo_msg("------------------------------") ;
-    ck0(sinfo_new_cubes_coadd(cpl_func,config, set, pro_ctg_cube),
-        "COADDING CUBES") ;
+    int compute_efficiency = 0;
+    cpl_frame* frm_std = cpl_frameset_find(set, RAW_STD);
 
-    sinfo_msg("------------------------------") ;
-    sinfo_msg("COADDED CUBES");
-    sinfo_msg("------------------------------") ;
-
-    /* ===============================================================
-     PSF
-     =============================================================== */
-
-    if((strcmp(pro_ctg_cube,PRO_COADD_PSF) == 0) ||
-                    (strcmp(pro_ctg_cube,PRO_COADD_STD) == 0) ||
-                    (strcmp(pro_ctg_cube,PRO_COADD_PUPIL) == 0) ) {
-
-
-        p = cpl_parameterlist_find(config, "sinfoni.psf.switch");
-        psf_sw = cpl_parameter_get_bool(p);
-        sinfo_msg("switch=%d",psf_sw);
-        if(psf_sw) {
-            sinfo_msg("------------------------------") ;
-            sinfo_msg("REDUCE PSF STD STAR FRAMES");
-            sinfo_msg("------------------------------") ;
-            if ( -1 == sinfo_new_psf(cpl_func,config,set,set) ) {
-                sinfo_msg_error("REDUCING PSF STD STAR FRAMES") ;
-                cpl_error_reset();
-            } else {
-                sinfo_msg("SUCCESS REDUCE PSF STD STAR FRAMES") ;
-            }
+    int niter=1;
+    if(frm_std != NULL) {
+        p = cpl_parameterlist_find(config,"sinfoni.stacked.flat_index");
+        flat_ind = cpl_parameter_get_bool(p);
+        cpl_frame* frm_std_cat = cpl_frameset_find(set, FLUX_STD_CATALOG);
+        cpl_frame* frm_atmext = cpl_frameset_find(set, EXTCOEFF_TABLE);
+        if ( frm_std_cat != NULL && frm_atmext != NULL ) {
+            check_nomsg(eff_set=cpl_frameset_duplicate(set));
+            compute_efficiency = 1;
+            niter=2;
         }
 
-        p = cpl_parameterlist_find(config, "sinfoni.std_star.switch");
-        std_sw = cpl_parameter_get_bool(p);
-        sinfo_msg("switch=%d",std_sw);
-        if(std_sw) {
-            sinfo_msg("------------------------------") ;
-            sinfo_msg("STD STAR DATA REDUCTION");
-            sinfo_msg("------------------------------") ;
-            if ( -1 == sinfo_new_stdstar(cpl_func,config, set,set ) ) {
-                sinfo_msg_error("REDUCING STD STAR DATA") ;
-                cpl_error_reset();
-            } else {
-                sinfo_msg("STD STAR DATA REDUCTION SUCCESS") ;
-            }
-        }
     }
 
+    for(int i=0; i< niter; i++) {
+        if( compute_efficiency == 1 ) {
+            if( i == 0 ) {
+                p = cpl_parameterlist_find(config,"sinfoni.stacked.flat_index");
+                cpl_parameter_set_bool(p,CPL_FALSE);
+                tmp_set=eff_set;
+            } else {
+                p = cpl_parameterlist_find(config,"sinfoni.stacked.flat_index");
+                cpl_parameter_set_bool(p,flat_ind);
+                tmp_set=set;
+                compute_efficiency = 0;
+            }
+        } else {
+            tmp_set=set;
+        }
+
+        /* ===============================================================
+           Defines several framesets each with a pair obj-sky,
+           stack each pair, put the results in set
+           =============================================================== */
+        ck0(sinfo_cub_stk_frames(config,&tmp_set,cpl_func,&pro_ctg_cube),
+            "Cannot stack RAW frames") ;
+
+        /* ===============================================================
+           SCI OBJNOD
+           =============================================================== */
+        sinfo_msg("------------------------------") ;
+        sinfo_msg("COADDING CUBES");
+        sinfo_msg("------------------------------") ;
+        ck0(sinfo_new_cubes_coadd(cpl_func,config, tmp_set, pro_ctg_cube),
+            "COADDING CUBES") ;
+
+        sinfo_msg("------------------------------") ;
+        sinfo_msg("COADDED CUBES");
+        sinfo_msg("------------------------------") ;
+
+        /* ===============================================================
+           PSF
+           =============================================================== */
+
+        if((strcmp(pro_ctg_cube,PRO_COADD_PSF) == 0) ||
+                        (strcmp(pro_ctg_cube,PRO_COADD_STD) == 0) ||
+                        (strcmp(pro_ctg_cube,PRO_COADD_PUPIL) == 0) ) {
+
+
+            p = cpl_parameterlist_find(config, "sinfoni.psf.switch");
+            psf_sw = cpl_parameter_get_bool(p);
+            sinfo_msg("switch=%d",psf_sw);
+            if(psf_sw) {
+                sinfo_msg("------------------------------") ;
+                sinfo_msg("REDUCE PSF STD STAR FRAMES");
+                sinfo_msg("------------------------------") ;
+                if ( -1 == sinfo_new_psf(cpl_func,config,tmp_set,tmp_set) ) {
+                    sinfo_msg_error("REDUCING PSF STD STAR FRAMES") ;
+                    cpl_error_reset();
+                } else {
+                    sinfo_msg("SUCCESS REDUCE PSF STD STAR FRAMES") ;
+                }
+            }
+
+            p = cpl_parameterlist_find(config, "sinfoni.std_star.switch");
+            std_sw = cpl_parameter_get_bool(p);
+            sinfo_msg("switch=%d",std_sw);
+            if(std_sw) {
+                sinfo_msg("------------------------------") ;
+                sinfo_msg("STD STAR DATA REDUCTION");
+                sinfo_msg("------------------------------") ;
+                if ( -1 == sinfo_new_stdstar(cpl_func,config, tmp_set,tmp_set ) ) {
+                    sinfo_msg_error("REDUCING STD STAR DATA") ;
+                    cpl_error_reset();
+                } else {
+                    sinfo_msg("STD STAR DATA REDUCTION SUCCESS") ;
+                }
+            }
+        }
+
+        if( compute_efficiency == 1 ) {
+
+            cpl_frame* frm_eff=cpl_frameset_find(tmp_set, PRO_EFFICIENCY);
+            if(frm_eff != NULL) {
+                cpl_frame* frm_tmp=cpl_frame_duplicate(frm_eff);
+                store_set=cpl_frameset_new();
+                cpl_frameset_insert(store_set,frm_tmp);
+            }
+            sinfo_free_frameset(&eff_set);
+
+        } else{
+            cpl_frameset_join(set,store_set);
+            sinfo_free_frameset(&store_set);
+        }
+
+    }
     cleanup:
-    sinfo_free_frameset(&ref_set);
+
     if (cpl_error_get_code() != CPL_ERROR_NONE) {
         sinfo_check_rec_status(0);
         return -1;
