@@ -213,7 +213,7 @@ static int sinfo_utl_skymap(
                 cpl_parameterlist   *   parlist,
                 cpl_frameset        *   framelist)
 {
-    cpl_parameter       *   param =NULL;
+
     const char *            name_i=NULL;
     int                    xsize=0;
     int                    ysize=0;
@@ -242,7 +242,7 @@ static int sinfo_utl_skymap(
     sinfo_msg("Welcome to SINFONI Pipeline release %d.%d.%d",
               SINFONI_MAJOR_VERSION,SINFONI_MINOR_VERSION,SINFONI_MICRO_VERSION);
 
-    param = cpl_parameterlist_find(parlist, 
+    cpl_parameter* param = cpl_parameterlist_find(parlist,
                     "sinfoni.sinfo_utl_skymap.out_filename");
     name_o = "out_skymap.fits";
 
