@@ -252,14 +252,14 @@ juldat(double *INDATE,
   C = DATE[1] + DATE[2]*1.E-2 + DATE[3]*1.E-4 + UT*1.E-6;
 
   if (C  >   1582.1015E0) {
-    IA=(int) (YP/100.D0);
+    IA=(int) (YP/100.);
     A=IA;
-    IB=2-IA+((int)(A/4.D0));
+    IB=2-IA+((int)(A/4.));
   } else {
     IB=0;
   }
 
-  *JD = ((int) (365.25E0*YP)) + ((int)(30.6001D0*(P+1.D0))) + DATE[3] + UT
+  *JD = ((int) (365.25E0*YP)) + ((int)(30.6001*(P+1.))) + DATE[3] + UT
     + IB + 1720994.5E0;
 
   /*
