@@ -215,13 +215,13 @@ sinfo_bp_dist_config_add(cpl_parameterlist *list)
     cpl_parameterlist_append(list, p);
 
     p = cpl_parameter_new_value("sinfoni.bp_dist.min_cut", CPL_TYPE_DOUBLE,
-                    "the minimum value of real data", "sinfoni.bp_dist", 0.1);
+                    "the minimum value of real data. For J band data taken after 31/01/2018 the default is 0.05.", "sinfoni.bp_dist", 0.1);
 
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "bp_dist-min_cut");
     cpl_parameterlist_append(list, p);
 
     p = cpl_parameter_new_value("sinfoni.bp_dist.max_cut", CPL_TYPE_DOUBLE,
-                    "the minimum value of real data", "sinfoni.bp_dist",
+                    "the maximum value of real data", "sinfoni.bp_dist",
                     50000.);
 
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "bp_dist-max_cut");
