@@ -207,14 +207,14 @@ sinfo_new_bp_search_lin(const char* plugin_id,
                             "QC BP-MAP LIN",deg," MED");
             sinfo_qclog_add_double(qclog_tbl,key_name,
                                    cpl_polynomial_get_coeff(pol,&deg),
-                                   "Linearity Polynomial Coeff","%g");
+                                   "Linearity Polynomial Coeff");
         }
         sinfo_free_polynomial(&pol);
 
         check_nomsg(p = cpl_parameterlist_find(config, "sinfoni.bp.method"));
         snprintf(key_value, MAX_NAME_SIZE-1,"%s",cpl_parameter_get_string(p));
         ck0_nomsg(sinfo_qclog_add_string(qclog_tbl,"QC BP-MAP METHOD",key_value,
-                        "BP search method","%s"));
+                        "BP search method"));
 
         ck0(sinfo_pro_save_tbl(det_lin,raw,sof,BP_LIN_LIN_DET_INFO_OUT_FILENAME,
                         PRO_LIN_DET_INFO,qclog_tbl,plugin_id,config),
@@ -243,15 +243,15 @@ sinfo_new_bp_search_lin(const char* plugin_id,
             snprintf(key_name,MAX_NAME_SIZE-1,"%s%i","QC GAIN",i);
             ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,
                             cpl_table_get_double(gain,"gain",i,status),
-                            "Detector gain","%g"));
+                            "Detector gain"));
         }
 
         ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC GAIN",
                         cpl_table_get_column_median(gain,"gain"),
-                        "Detector gain median","%g"));
+                        "Detector gain median"));
         ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC GAINERR",
                         cpl_table_get_column_stdev(gain,"gain"),
-                        "Detector gain error","%g"));
+                        "Detector gain error"));
 
         ck0(sinfo_pro_save_tbl(gain,raw,sof,BP_LIN_GAIN_OUT_FILENAME,
                         PRO_GAIN_INFO,qclog_tbl,plugin_id,config),
@@ -306,14 +306,14 @@ sinfo_new_bp_search_lin(const char* plugin_id,
         snprintf(key_value,MAX_NAME_SIZE-1,"%g",cpl_vector_get(cube_mean,i));
         ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,
                         cpl_vector_get(cube_mean,i),
-                        "Linearity Polynomial Coeff","%g"));
+                        "Linearity Polynomial Coeff"));
 
     }
     sinfo_free_my_vector(&cube_mean);
     check_nomsg(p = cpl_parameterlist_find(config, "sinfoni.bp.method"));
     snprintf(key_value, MAX_NAME_SIZE-1,"%s",cpl_parameter_get_string(p));
     ck0_nomsg(sinfo_qclog_add_string(qclog_tbl,"QC BP-MAP METHOD",key_value,
-                    "BP search method","%s"));
+                    "BP search method"));
 
 
     ck0(sinfo_pro_save_ims(coeffs_imgl,raw,sof,cfg->coeffsCubeName,
@@ -344,10 +344,10 @@ sinfo_new_bp_search_lin(const char* plugin_id,
     check_nomsg(p = cpl_parameterlist_find(config, "sinfoni.bp.method"));
     snprintf(key_value, MAX_NAME_SIZE-1,"%s",cpl_parameter_get_string(p));
     ck0_nomsg(sinfo_qclog_add_string(qclog_tbl,"QC BP-MAP METHOD",key_value,
-                    "BP search method","%s"));
+                    "BP search method"));
 
     ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC BP-MAP NBADPIX",n_bad,
-                    "No of bad pixels","%d"));
+                    "No of bad pixels"));
 
     ck0(sinfo_pro_save_ima(mask,raw,sof,cfg->outName,PRO_BP_MAP_NL,qclog_tbl,
                     plugin_id,config),
