@@ -129,9 +129,9 @@ sinfo_new_bp_search_noise (const char* plugin_id,
     check_nomsg(p = cpl_parameterlist_find(config, "sinfoni.bp.method"));
     snprintf(key_value, MAX_NAME_SIZE-1,"%s",cpl_parameter_get_string(p));
     ck0_nomsg(sinfo_qclog_add_string(qclog_tbl,"QC BP-MAP METHOD",key_value,
-                    "BP search method","%s"));
+                    "BP search method"));
     ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC BP-MAP NBADPIX",n_bad,
-                    "No of bad pixels","%d"));
+                    "No of bad pixels"));
 
     ck0(sinfo_pro_save_ima(mask,raw,sof,(char *) out_name,
                     PRO_BP_MAP_HP,qclog_tbl,plugin_id,config),
