@@ -326,11 +326,11 @@ sinfo_new_bp_search_normal(const char* plugin_id, cpl_parameterlist* config,
 
     ck0_nomsg(
                     sinfo_qclog_add_string(qclog_tbl, "QC BP-MAP METHOD",
-                                    key_value, "BP search method", "%s"));
+                                    key_value, "BP search method"));
 
     ck0_nomsg(
                     sinfo_qclog_add_int(qclog_tbl, "QC BP-MAP NBADPIX", n,
-                                    "No of bad pixels", "%d"));
+                                    "No of bad pixels"));
 
     ck0(
                     sinfo_pro_save_ima(maskImage, ref_set, sof, cfg->outName,
