@@ -553,12 +553,12 @@ sinfo_north_south_test( cpl_image * ns_image,
                 mpar[k] = 1 ;
             }
             /* finally, do the least square fit using a Gaussian */
-            int iters;
-            if ( 0 > ( iters = sinfo_new_lsqfit_c( xdat, &xdim, 
+            //int iters;
+            if ( 0 > sinfo_new_lsqfit_c( xdat, &xdim,
                                                    line -> data, wdat, &ndat, 
                                                    (*par) -> fit_par,
                                                    (*par) -> derv_par, mpar, 
-                                                   &numpar, &tol, &its, &lab)) )
+                                                   &numpar, &tol, &its, &lab) )
             {
           /*
                 cpl_msg_debug ("north_south_test:",
@@ -612,8 +612,8 @@ sinfo_north_south_test( cpl_image * ns_image,
 
         if ( counter != n_slitlets )
         {
-            continue ;
             sinfo_msg_warning("wrong number of slitlets found in row: %d",row);
+            continue ;
         }
         /* store the distances between the sources in a buffer */
         for ( i = 1 ; i < n_slitlets ; i++ )
