@@ -467,12 +467,12 @@ sinfo_get_pupil_shift(cpl_imagelist* iml,const int n,cpl_table** qclog_tbl)
     yshift=max_ima_cy-(double)ny/2;
 
     snprintf(key_name,sizeof(key_name),"%s%d%s","QC PUPIL",n," SHIFTX");
-    sinfo_qclog_add_double(*qclog_tbl,key_name,xshift,
-                           "X shift centroid - center image","%f");
+    sinfo_qclog_add_double_f(*qclog_tbl,key_name,xshift,
+                           "X shift centroid - center image");
 
     snprintf(key_name,sizeof(key_name),"%s%d%s","QC PUPIL",n," SHIFTY");
-    sinfo_qclog_add_double(*qclog_tbl,key_name,yshift,
-                           "Y shift centroid - center image","%f");
+    sinfo_qclog_add_double_f(*qclog_tbl,key_name,yshift,
+                           "Y shift centroid - center image");
     cpl_image_delete(img);
 
     return 0;
@@ -549,6 +549,30 @@ double sinfo_get_wave_cent(const char* band)
 
 }
 
+
+/**
+   @brief    Set dispersion as a function of band
+   @param    band    input band
+   @return   dispersion
+   @note since the detector was upgrade to 2K Hawaii we use for the dispersion
+   the values originally thought about for the old detector in dither mode
+ */
+
+double sinfo_get_dispersion(const char* band)
+{
+    double disp=0.;
+    if (strcmp(band,"H+K") == 0) {
+        disp=DISPERSION_HK_DITH;
+    } else if (strcmp(band,"K") == 0) {
+        disp=DISPERSION_K_DITH;
+    } else if (strcmp(band,"J") == 0) {
+        disp=DISPERSION_J_DITH;
+    } else if (strcmp(band,"H") == 0) {
+        disp=DISPERSION_H_DITH;
+    }
+    return disp;
+
+}
 /**
    @brief    Check if pixel scale changes
    @param    pix_scale    input pixel scale
