@@ -102,11 +102,11 @@ sinfo_fftn(
     unsigned   i2rev=0;
     unsigned   i3rev=0;
     unsigned   ibit=0;
-    unsigned   ip2=0;
+
     unsigned   ifp1=0;
     unsigned   ifp2=0;
     unsigned   k2=0;
-    unsigned   n=0;
+
     unsigned   nprev = 1;
     unsigned   ntot = 1;
     register   unsigned i2=0;
@@ -124,9 +124,9 @@ sinfo_fftn(
     }
 
     for (idim = ndim - 1; idim >= 0; --idim) {
-        n = nn[idim];
+    	 unsigned   n = nn[idim];
 
-        ip2 = nprev * n;        /*  Unit step for next dimension */
+        unsigned   ip2 = nprev * n;        /*  Unit step for next dimension */
         i2rev = 0;              /*  Bit reversed i2 */
 
         /*      This is the bit reversal section of the routine */
