@@ -1368,9 +1368,9 @@ float sinfo_new_determine_conversion_factor ( cpl_imagelist * cube,
         mpar[i] = 1 ;
     }
     int fitInd ;
-    if ( -1 == (fitInd = sinfo_new_fit_2d_gaussian(summedIm, fit_par, derv_par,
+    if ( -1 == sinfo_new_fit_2d_gaussian(summedIm, fit_par, derv_par,
                                                    mpar, llx, lly, halfbox_x, 
-                                                   halfbox_y, check)) )
+                                                   halfbox_y, check) )
     {
         sinfo_msg_warning("sinfo_fit2dGaussian failed!") ;
         cpl_image_delete( summedIm) ;
