@@ -109,4 +109,6 @@
 #define SKYSPIDER_OUT_FILENAME "out_objnod.fits"
 #define SKYSPIDER_MASK_OUT_FILENAME "out_mask_cube_spider.fits"
 #define EFFICIENCY_FILENAME "out_efficiency.fits"
+#define SPECTRA_FLUXCAL_FILENAME "out_spectra_fluxcal.fits"
+#define RESPONSE_FILENAME "out_response.fits"
 #endif
