@@ -752,7 +752,7 @@ cpl_image * sinfo_new_col_tilt ( cpl_image * image, float sigmaFactor )
          * sinfo_median is the mean of colnum/2-1 th and colnum/2 th value.
          */
 
-        if ( colnum % 2 == 1 )
+        if ( colnum % 2 == 1 || colnum == 0)
         {
             sinfo_median = column[colnum/2] ;
         }
