@@ -234,7 +234,7 @@ sinfo_new_add_bp_map (const char* plugin_id,
         sinfo_msg ("number of bad pixels: %d\n", n_bad) ;
         cknull_nomsg(qclog_tbl = sinfo_qclog_init());
         ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC MBP_MAP NBADPIX",
-                        n_bad,"No of bad pixels","%d"));
+                        n_bad,"No of bad pixels"));
 
         if (nmsk>1) {
             ck0(sinfo_pro_save_ima(img_tot,ref_set,sof,out_msk,
