@@ -756,7 +756,7 @@ sinfo_new_c_bezier_interpol(cpl_imagelist * im, cpl_imagelist * action)
     new_XYZW res;
     new_XYZW selected;
     float step, cumstep, selected_distance;
-    new_Dim *point;
+    new_Dim *point=NULL;
     double munk;
     int ilx = 0;
     int ily = 0;
@@ -809,7 +809,7 @@ sinfo_new_c_bezier_interpol(cpl_imagelist * im, cpl_imagelist * action)
                     else {
 #ifdef DEBUG
                         sinfo_msg_debug("Ignored im[%d,%d,%d]=%lf reason:%f",
-                                        i,j,k,pidata[sinfo_im_xy(im,i,j)],
+                                        i,j,k,pidata[pix],
                                         padata[pix]);
 #endif
                     }
