@@ -640,7 +640,7 @@ sinfo_new_cubes_build(const char* plugin_id, cpl_parameterlist* config,
             ck0_nomsg(
                             sinfo_qclog_add_int(qclog_tbl, "QC SKYCOR THBKGFIT",
                                             sqc->th_fit,
-                                            "Thermal background fit success", "%d"));
+                                            "Thermal background fit success"));
 
             ck0(
                             sinfo_pro_save_ims(obj_cor, sof, sof, file_name, pro_obs,
