@@ -43,6 +43,7 @@ nodding observations
 #include "sinfo_cube_construct.h"
 #include "sinfo_error.h"
 #include "sinfo_utils_wrappers.h"
+#include "sinfo_utl_efficiency.h"
 //Used only for cpl_propertylist_has
 #include "sinfo_dfs.h"
 /*----------------------------------------------------------------------------
@@ -93,7 +94,7 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
 
     int i=0;
     int n=0 ;
-    /* int partind = 0 ; */
+
     int centralpix=0 ;
     int z_siz=0;
     int z_min=0;
@@ -108,15 +109,7 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
     float ref_offy=0;
     float newcenter_x=0 ;
     float newcenter_y=0 ;
-    /*
-   float cd1_1=0;
-   float cd1_2=0;
-   float cd2_1=0;
-   float cd2_2=0;
-   double pixelscale=0;
-     */
-    //double angle=0;
-    //float radangle=0 ;
+
     double exptime=0 ;
 
     double * times=NULL ;
@@ -182,23 +175,17 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
     }
 
     /*----parse input data and parameters to set cube_config cfg---*/
-    check_nomsg(stk = cpl_frameset_new());
+    stk = cpl_frameset_new();
 
-    cknull(cfg = sinfo_parse_cpl_input_objnod(config,sof,&stk),
-           "Error setting parameter configuration");
+    cfg = sinfo_parse_cpl_input_objnod(config,sof,&stk);
 
-    ck0(sinfo_check_input_data(cfg),"error checking input");
+    sinfo_check_input_data(cfg);
 
     if ( cfg->jitterind == 1 )
     {
-        cknull(times = (double*) cpl_calloc (cfg->nframes, sizeof (double)),
-                        " could not allocate memory!") ;
-
-        cknull(offsetx = (float*) cpl_calloc (cfg->nframes, sizeof(float)),
-               " could not allocate memory!") ;
-
-        cknull(offsety = (float*) cpl_calloc (cfg->nframes, sizeof(float)),
-               " could not allocate memory!") ;
+        times = (double*) cpl_calloc (cfg->nframes, sizeof (double));
+        offsetx = (float*) cpl_calloc (cfg->nframes, sizeof(float));
+        offsety = (float*) cpl_calloc (cfg->nframes, sizeof(float));
     }
 
     if (cfg->jitterind == 0)
@@ -210,10 +197,8 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
         }
     }
 
-    ck0(sinfo_auto_size_cube_new(cfg,&ref_offx,&ref_offy,
-                    &offx_min,&offy_min,
-                    &offx_max,&offy_max),
-        "Error resizing cube");
+    sinfo_auto_size_cube_new(cfg,&ref_offx,&ref_offy,&offx_min,&offy_min,
+                             &offx_max,&offy_max);
 
     if(NULL != cpl_frameset_find(sof,PRO_ILL_COR)) {
         frame = cpl_frameset_find(sof,PRO_ILL_COR);
@@ -237,7 +222,6 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
             goto cleanup;
         }
 
-
         /* get some header values and compute the CD-sinfo_matrix */
         plist=cpl_propertylist_load(name,0);
 
@@ -249,7 +233,6 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
             return -1;
         }
 
-
         //pixelscale = sinfo_pfits_get_pixscale(plist) /2;
         //angle = sinfo_pfits_get_posangle(plist) ;
         /* in PUPIL data there is not posangle info: we reset the error */
@@ -258,14 +241,6 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
         }
 
         sinfo_free_propertylist(&plist);
-        // The following 5 lines are not really used here!
-        /*
-      radangle = angle * PI_NUMB / 180. ;
-      cd1_1 = cos(radangle) ;
-      cd1_2 = sin(radangle) ;
-      cd2_1 = -sin(radangle) ;
-      cd2_2 = cos(radangle) ;
-         */
 
         sinfo_msg_debug("frame no.: %d, name: %s\n", n, name) ;
         cknull(im = cpl_image_load(name,CPL_TYPE_FLOAT,0,0),
@@ -291,7 +266,6 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
 
     } /* end loop over n (nframes) */
 
-
     /* leak free */
     if(cfg->jitterind == 0) {
         goto exit;
@@ -308,25 +282,22 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
 
     if ( cfg->jitterind == 1 )
     {
-        check_nomsg(p = cpl_parameterlist_find(config, "sinfoni.objnod.vllx"));
-        check_nomsg(vllx = cpl_parameter_get_int(p));
-        check_nomsg(p = cpl_parameterlist_find(config, "sinfoni.objnod.vlly"));
-        check_nomsg(vlly = cpl_parameter_get_int(p));
-        check_nomsg(p = cpl_parameterlist_find(config, "sinfoni.objnod.vurx"));
-        check_nomsg(vurx = cpl_parameter_get_int(p));
-        check_nomsg(p = cpl_parameterlist_find(config, "sinfoni.objnod.vury"));
-        check_nomsg(vury = cpl_parameter_get_int(p));
-        cknull(cube_tmp = (cpl_imagelist**) cpl_calloc (cfg->nframes,
-                        sizeof (cpl_imagelist*)),
-                        "Could not allocate memory for cube_tmp");
+        p = cpl_parameterlist_find(config, "sinfoni.objnod.vllx");
+        vllx = cpl_parameter_get_int(p);
+        p = cpl_parameterlist_find(config, "sinfoni.objnod.vlly");
+        vlly = cpl_parameter_get_int(p);
+        p = cpl_parameterlist_find(config, "sinfoni.objnod.vurx");
+        vurx = cpl_parameter_get_int(p);
+        p = cpl_parameterlist_find(config, "sinfoni.objnod.vury");
+        vury = cpl_parameter_get_int(p);
+        cube_tmp = (cpl_imagelist**) cpl_calloc (cfg->nframes,
+                        sizeof (cpl_imagelist*));
 
 
-        cknull(cubeobject = (cpl_imagelist**) cpl_calloc (cfg->nframes,
-                        sizeof (cpl_imagelist*)),
-                        "Could not allocate memory for cubeobject");
-        check_nomsg(p=cpl_parameterlist_find(config,
-                        "sinfoni.objnod.sky_cor"));
-        check_nomsg(sky_cor=cpl_parameter_get_bool(p));
+        cubeobject = (cpl_imagelist**) cpl_calloc (cfg->nframes,
+                        sizeof (cpl_imagelist*));
+        p=cpl_parameterlist_find(config,"sinfoni.objnod.sky_cor");
+        sky_cor=cpl_parameter_get_bool(p);
 
 
         for ( n = 0 ; n < cfg->nframes ; n++ ) {
@@ -341,23 +312,18 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
                 snprintf(file_name,MAX_NAME_SIZE-1,"%s%2.2d%s","out_cube_obj",n,
                                 ".fits");
             }
-            check_nomsg(cube_tmp[n] = cpl_imagelist_load(file_name,
-                            CPL_TYPE_FLOAT,0));
+            cube_tmp[n] = cpl_imagelist_load(file_name,CPL_TYPE_FLOAT,0);
 
 
-            check_nomsg(cubeobject[n] = sinfo_new_cube_getvig(
-                            cube_tmp[n],
-                            1+vllx,1+vlly,
-                            64 - vurx, 64 - vury));
-            check_nomsg(sinfo_free_imagelist(&cube_tmp[n]));
+            cubeobject[n] = sinfo_new_cube_getvig(cube_tmp[n],1+vllx,1+vlly,
+                            64 - vurx, 64 - vury);
+            sinfo_free_imagelist(&cube_tmp[n]);
 
         }
         sinfo_free_array_imagelist(&cube_tmp);
 
-
     }
 
-
     /*
      ---------------------------------------------------------------------
      ------------------------JITTERING------------------------------------
@@ -368,25 +334,15 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
     {
         sinfo_msg("Jittering...");
 
-        sinfo_msg("Coadded cube size. x: %d y: %d",
-                  cfg->size_x,cfg->size_y);
-        check_nomsg(jittercube = cpl_imagelist_new()) ;
-
-
-        /*
-         ---------------------------------------------------------------------
-         -------------------THOMAS ALGORITHM----------------------------------
-         ---------------------------------------------------------------------
-         */
-
-        check_nomsg(p=cpl_parameterlist_find(config,
-                        "sinfoni.objnod.scales_sky"));
-        check_nomsg(scales_sky=cpl_parameter_get_bool(p));
-        check_nomsg(p=cpl_parameterlist_find(config,"sinfoni.objnod.ks_clip"));
-        check_nomsg(ks_clip = cpl_parameter_get_bool(p));
-        check_nomsg(p=cpl_parameterlist_find(config,"sinfoni.objnod.kappa"));
-        check_nomsg(kappa = cpl_parameter_get_double(p));
+        sinfo_msg("Coadded cube size. x: %d y: %d", cfg->size_x,cfg->size_y);
+        jittercube = cpl_imagelist_new() ;
 
+        p=cpl_parameterlist_find(config,"sinfoni.objnod.scales_sky");
+        scales_sky=cpl_parameter_get_bool(p);
+        p=cpl_parameterlist_find(config,"sinfoni.objnod.ks_clip");
+        ks_clip = cpl_parameter_get_bool(p);
+        p=cpl_parameterlist_find(config,"sinfoni.objnod.kappa");
+        kappa = cpl_parameter_get_double(p);
 
         if(scales_sky == 1) {
             sinfo_msg("Subtract spatial sinfo_median to each cube plane");
@@ -396,10 +352,7 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
             }
         }
 
-
-        /* AMO CHECK */
-
-        cknull(maskcube=cpl_imagelist_new(),"could not allocate cube!");
+        maskcube=cpl_imagelist_new();
 
         /* Illumination correction */
         if(ill_cor != NULL) {
@@ -415,7 +368,7 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
         if(ks_clip == 1) {
             sinfo_msg("Cube coaddition with kappa-sigma");
         }
-        check_nomsg(onp=cpl_imagelist_get_size(cubeobject[0]));
+        onp=cpl_imagelist_get_size(cubeobject[0]);
         for(z=0;z<onp;z+=z_stp) {
             z_siz=(z_stp < (onp-z)) ? z_stp : (onp-z);
             z_min=z;
@@ -424,36 +377,21 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
                       z_min,z_max,onp);
 
             for(j=z_min;j<z_max;j++) {
-                check_nomsg(j_img=cpl_image_new(cfg->size_x,
-                                cfg->size_y,CPL_TYPE_FLOAT));
-                check_nomsg(cpl_imagelist_set(jittercube,j_img,j));
-                check_nomsg(m_img = cpl_image_new(cfg->size_x,
-                                cfg->size_y,CPL_TYPE_FLOAT));
-                check_nomsg(cpl_imagelist_set(maskcube,m_img,j));
+                j_img=cpl_image_new(cfg->size_x,cfg->size_y,CPL_TYPE_FLOAT);
+                cpl_imagelist_set(jittercube,j_img,j);
+                m_img = cpl_image_new(cfg->size_x,cfg->size_y,CPL_TYPE_FLOAT);
+                cpl_imagelist_set(maskcube,m_img,j);
             }
             if(ks_clip == 1) {
                 sinfo_new_combine_jittered_cubes_thomas_range(cubeobject,
-                                jittercube,
-                                maskcube,
-                                cfg->nframes,
-                                offsetx,offsety,
-                                times,
-                                cfg->kernel_type,
-                                z_min,
-                                z_max,
+                                jittercube,maskcube,cfg->nframes,offsetx,
+                                offsety,times,cfg->kernel_type,z_min,z_max,
                                 kappa);
 
             } else {
-                sinfo_new_combine_jittered_cubes_range(cubeobject,
-                                jittercube,
-                                maskcube,
-                                cfg->nframes,
-                                offsetx,
-                                offsety,
-                                times,
-                                cfg->kernel_type,
-                                z_min,
-                                z_max) ;
+                sinfo_new_combine_jittered_cubes_range(cubeobject,jittercube,
+                                maskcube,cfg->nframes,offsetx,offsety,
+                                times,cfg->kernel_type,z_min,z_max) ;
             }
         }
         sinfo_new_convert_0_to_ZERO_for_cubes(jittercube) ;
@@ -476,27 +414,6 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
         }
         sinfo_free_array_imagelist(&cubeobject);
 
-        //Old setting
-        //newcenter_x = cfg->size_x / 2. + 0.5 ;
-        //newcenter_y = cfg->size_y / 2. + 0.5 ;
-
-
-        /* new setting */
-        /*
-        sinfo_msg("offx_min=%f,offy_min=%f",offx_min,offy_min);
-        sinfo_msg("offx_max=%f,offy_max=%f",offx_max,offy_max);
-        sinfo_msg("ref_offx=%f,ref_offy=%f",ref_offx,ref_offy);
-
-        newcenter_x=2*floor(fabs(offx_min)+0.5)+32+8;
-        newcenter_y=-2*floor(fabs(offy_max)+0.5)+32-2;
-
-
-        newcenter_x=cfg->size_x / 2. -offsetx[0];
-        newcenter_y=cfg->size_y / 2. -offsety[0];
-         */
-
-
-
         if (mjd_obs > 53825. ) {
             /* April 1st 2006 */
             newcenter_x=cfg->size_x / 2. +2*ref_offx;
@@ -511,39 +428,26 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
             newcenter_y=cfg->size_y / 2. -2*ref_offy;
         }
 
-
-        //sinfo_msg("CRPIX=%f,%f", newcenter_x, newcenter_y);
-        //newcenter_x=2*floor(fabs(ref_offx)+0.5);
-        //newcenter_y=-2*floor(fabs(ref_offy)+0.5);
-        //sinfo_msg_warning("Center image: %f %f",newcenter_x,newcenter_y);
-        cknull_nomsg(qclog = sinfo_qclog_init());
+        qclog = sinfo_qclog_init();
         plist=cpl_propertylist_load(file_name,0);
         if(sinfo_baryvel(plist, &barycor,&helicor) != CPL_ERROR_NONE) {
             sinfo_msg_warning("Could not compute velocity corrections");
             cpl_error_reset();
         } else {
 
-            check_nomsg(sinfo_qclog_add_double(qclog,
-                            "QC VRAD BARYCOR",
-                            barycor,
-                            "Barycentric radial velocity correction ",
-                            "%13.6f"));
+            sinfo_qclog_add_double_format(qclog,"QC VRAD BARYCOR",barycor,
+                            "Barycentric radial velocity correction ");
 
-            check_nomsg(sinfo_qclog_add_double(qclog,
-                            "QC VRAD HELICOR",
-                            helicor,
-                            "Heliocentric radial velocity correction ",
-                            "%13.6f"));
+            sinfo_qclog_add_double_format(qclog,"QC VRAD HELICOR",helicor,
+                            "Heliocentric radial velocity correction ");
             sinfo_msg("Barycor=%g Helicor=%g",barycor,helicor);
 
             sinfo_free_propertylist(&plist);
 
         }
 
-        ck0(sinfo_pro_save_ims(jittercube,sof,sof,cfg->outName,
-                        procatg,qclog,plugin_id,config),
-            "cannot save cube %s", cfg->outName);
-
+        sinfo_pro_save_ims(jittercube,sof,sof,cfg->outName,procatg,qclog,
+                           plugin_id,config);
         sinfo_free_table(&qclog);
 
         /* we need to set again the following 3 */
@@ -552,41 +456,38 @@ sinfo_new_cubes_coadd (const char* plugin_id,cpl_parameterlist* config,
         centralLambda=sinfo_pfits_get_crval3(plist);
         centralpix=sinfo_pfits_get_crpix3(plist);
         sinfo_free_propertylist(&plist);
-        sinfo_new_set_wcs_cube(jittercube, cfg->outName,
-                               centralLambda, dis,
+        sinfo_new_set_wcs_cube(jittercube, cfg->outName,centralLambda, dis,
                                centralpix, newcenter_x, newcenter_y);
 
-        cknull(jitter_image = sinfo_new_median_cube(jittercube),
-               " could not do sinfo_medianCube()");
-        cknull_nomsg(qclog = sinfo_qclog_init());
+        jitter_image = sinfo_new_median_cube(jittercube);
+        qclog = sinfo_qclog_init();
         update_bad_pixel_map(jitter_image);
-        check_nomsg(sinfo_qclog_add_double(qclog,
-                        "QC FRMDIF MEANSTD",
+        sinfo_qclog_add_double_format(qclog,"QC FRMDIF MEANSTD",
                         cpl_image_get_mean(jitter_image),
-                        "mean of the collapesd cube",
-                        "%13.6f"));
-        check_nomsg(sinfo_qclog_add_double(qclog,
-                        "QC FRMDIF STDEV",
+                        "mean of the collapesd cube");
+        sinfo_qclog_add_double_format(qclog,"QC FRMDIF STDEV",
                         cpl_image_get_stdev(jitter_image),
-                        "standard deviation of the collapesd cube",
-                        "%13.6f"));
-        ck0(sinfo_pro_save_ima(jitter_image,sof,sof,cfg->med_cube_name,
-                        pro_med,qclog,plugin_id,config),
-            "cannot save ima %s", cfg->outName);
+						"standard deviation of the collapesd cube");
+        sinfo_pro_save_ima(jitter_image,sof,sof,cfg->med_cube_name,pro_med,
+        		qclog,plugin_id,config);
+
         sinfo_free_table(&qclog);
 
+
+        if( sinfo_can_flux_calibrate(sof) ) {
+        	sinfo_flux_calibrate_cube(procatg, plugin_id, config, sof, sof);
+        }
+
         sinfo_new_set_wcs_image(jitter_image, cfg->med_cube_name,
                                 newcenter_x,newcenter_y);
 
         sinfo_free_image(&jitter_image);
 
-        ck0(sinfo_pro_save_ims(maskcube,sof,sof,cfg->maskname,
-                        pro_mjit,NULL,plugin_id,config),
-            "cannot save cube %s", cfg->maskname);
+        sinfo_pro_save_ims(maskcube,sof,sof,cfg->maskname,pro_mjit,NULL,
+                           plugin_id,config);
 
-        sinfo_new_set_wcs_cube(maskcube, cfg->maskname,
-                               centralLambda, dis, centralpix,
-                               newcenter_x, newcenter_y);
+        sinfo_new_set_wcs_cube(maskcube, cfg->maskname,centralLambda, dis,
+                               centralpix,newcenter_x, newcenter_y);
 
         sinfo_free_double(&times) ;
         sinfo_free_float(&offsetx) ;
