@@ -325,20 +325,20 @@ int sinfo_new_dark (const char* plugin_id, cpl_parameterlist* config,
         /* QC LOG */
         cknull_nomsg(qclog_tbl = sinfo_qclog_init());
 
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC DARKMED AVE",
-                        qc_darkmed_ave,"Average of raw darks medians","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC DARKMED AVE",
+                        qc_darkmed_ave,"Average of raw darks medians"));
 
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC DARKMED STDEV",
-                        qc_darkmed_stdev,"STDEV of raw darks medians","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC DARKMED STDEV",
+                        qc_darkmed_stdev,"STDEV of raw darks medians"));
 
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC RON",
-                        qc_ron_val,"Read Out Noise","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC RON",
+                        qc_ron_val,"Read Out Noise"));
 
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC RONRMS",
-                        qc_ron_err,"RMS on Read Out Noise","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC RONRMS",
+                        qc_ron_err,"RMS on Read Out Noise"));
 
         ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC DARKFPN",
-                        fpn,"Fixed Pattern Noise of combined frames","%g"));
+                        fpn,"Fixed Pattern Noise of combined frames"));
 
 
         /* special way to calculate RON: for each couple */
@@ -406,7 +406,7 @@ int sinfo_new_dark (const char* plugin_id, cpl_parameterlist* config,
 
         cknull_nomsg(qclog_tbl = sinfo_qclog_init());
         ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC NAME",1,
-                        "A description","%d"));
+                        "A description"));
 
         ck0(sinfo_pro_save_ima(image,raw,sof,dark_name,
                         PRO_MASTER_DARK,qclog_tbl,plugin_id,config),
@@ -443,7 +443,7 @@ int sinfo_new_dark (const char* plugin_id, cpl_parameterlist* config,
 
         cknull_nomsg(qclog_tbl = sinfo_qclog_init());
         ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC NAME",1,
-                        "A description","%d"));
+                        "A description"));
 
         ck0(sinfo_pro_save_ima(eclipse_image,raw,sof,dark_name,
                         PRO_MASTER_DARK,qclog_tbl,plugin_id,config),
@@ -480,7 +480,7 @@ int sinfo_new_dark (const char* plugin_id, cpl_parameterlist* config,
                 sinfo_msg("dark_name-%s\n",dark_name);
                 cknull_nomsg(qclog_tbl = sinfo_qclog_init());
                 ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC NAME",1,
-                                "A description","%d"));
+                                "A description"));
 
                 ck0(sinfo_pro_save_ima(image,raw,sof,dark_name,
                                 PRO_MASTER_DARK,qclog_tbl,plugin_id,config),
@@ -512,7 +512,7 @@ int sinfo_new_dark (const char* plugin_id, cpl_parameterlist* config,
 
                 cknull_nomsg(qclog_tbl = sinfo_qclog_init());
                 ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC NAME",1,
-                                "A description","%d"));
+                                "A description"));
 
                 ck0(sinfo_pro_save_ima(image,raw,sof,dark_name,
                                 PRO_MASTER_DARK,qclog_tbl,plugin_id,config),
@@ -542,7 +542,7 @@ int sinfo_new_dark (const char* plugin_id, cpl_parameterlist* config,
 
                 cknull_nomsg(qclog_tbl = sinfo_qclog_init());
                 ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC NAME",1,
-                                "A description","%d"));
+                                "A description"));
 
                 ck0(sinfo_pro_save_ima(image,raw,sof,dark_name,
                                 PRO_MASTER_DARK,qclog_tbl,plugin_id,config),
@@ -638,8 +638,8 @@ sinfo_dark_ron_reduce(cpl_frameset    *   framelist,
         /* Write QC LOG */
 
         snprintf(key_name,MAX_NAME_SIZE-1,"%s%d","QC RON",i+1);
-        sinfo_qclog_add_double(qclog_tbl,key_name,ron[i],
-                               "Read Out Noise","%f");
+        sinfo_qclog_add_double_f(qclog_tbl,key_name,ron[i],
+                               "Read Out Noise");
 
     }
 
