@@ -608,54 +608,54 @@ sinfo_new_find_distortions(const char* plugin_id,
      check_nomsg(qclog_tbl = sinfo_qclog_init());
      snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%d","QC COEFF",0,0);
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,pcf[0][0],
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%d","QC COEFF",1,0);
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,pcf[1][0],
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%d","QC COEFF",0,1);
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,pcf[0][1],
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%d","QC COEFF",1,1);
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,pcf[1][1],
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%d","QC COEFF",2,0);
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,pcf[2][0],
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%d","QC COEFF",0,2);
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,pcf[0][2],
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%d","QC COEFF",2,1);
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,pcf[2][1],
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%d","QC COEFF",1,2);
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,pcf[1][2],
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%d","QC COEFF",3,0);
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,pcf[3][0],
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%d","QC COEFF",0,3);
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,pcf[0][3],
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      snprintf(key_name,MAX_NAME_SIZE-1,"%s","QC OFFSET");
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,value,
-                     "Polynomial distortion coefficient","%g"));
+                     "Polynomial distortion coefficient"));
 
      xshift=new_compute_shift(x_c,y_c,pcf[0][0],pcf[1][0],pcf[0][1],
                      pcf[1][1],pcf[2][0],pcf[0][2],
                      pcf[2][1],pcf[1][2],pcf[3][0],pcf[0][3]);
 
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC XSHIFT CC",xshift,
-                     "X shift in x_c,y_c","%g"));
+                     "X shift in x_c,y_c"));
 
 
      xshift=new_compute_shift(x_l,y_l,pcf[0][0],pcf[1][0],pcf[0][1],
@@ -663,21 +663,21 @@ sinfo_new_find_distortions(const char* plugin_id,
                      pcf[2][1],pcf[1][2],pcf[3][0],pcf[0][3]);
 
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC XSHIFT LL",xshift,
-                     "X shift in x_l,y_l","%g"));
+                     "X shift in x_l,y_l"));
 
      xshift=new_compute_shift(x_l,y_u,pcf[0][0],pcf[1][0],pcf[0][1],
                      pcf[1][1],pcf[2][0],pcf[0][2],
                      pcf[2][1],pcf[1][2],pcf[3][0],pcf[0][3]);
 
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC XSHIFT UL",xshift,
-                     "X shift in x_l,y_u","%g"));
+                     "X shift in x_l,y_u"));
 
      xshift=new_compute_shift(x_u,y_u,pcf[0][0],pcf[1][0],pcf[0][1],
                      pcf[1][1],pcf[2][0],pcf[0][2],
                      pcf[2][1],pcf[1][2],pcf[3][0],pcf[0][3]);
 
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC XSHIFT UR",xshift,
-                     "X shift in x_u,y_u","%g"));
+                     "X shift in x_u,y_u"));
 
 
      xshift=new_compute_shift(x_u,y_l,pcf[0][0],pcf[1][0],pcf[0][1],
@@ -685,7 +685,7 @@ sinfo_new_find_distortions(const char* plugin_id,
                      pcf[2][1],pcf[1][2],pcf[3][0],pcf[0][3]);
 
      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC XSHIFT LR",xshift,
-                     "X shift in x_u,y_l","%g"));
+                     "X shift in x_u,y_l"));
 
 
      ck0(sinfo_pro_save_tbl(poly_tbl,set_fibre_ns,sof,cfg->outName,
