@@ -481,7 +481,7 @@ sinfo_new_lamp_flats (const char* plugin_id,
 
         cknull_nomsg(qclog_tbl = sinfo_qclog_init());
         ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC BP-MAP NBADPIX",n_badpixels,
-                        "No of bad pixels","%d"));
+                        "No of bad pixels"));
 
         ck0(sinfo_pro_save_ima(maskImage,ref_set,sof,cfg->maskname,
                         PRO_BP_MAP,qclog_tbl,plugin_id,config),
@@ -653,24 +653,22 @@ sinfo_new_lamp_flats (const char* plugin_id,
     ck0(new_lamp_flats_det_ncounts(raw,cfg),"error computing number of counts");
     cknull_nomsg(qclog_tbl = sinfo_qclog_init());
     ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC SPECFLAT NCNTSAVG",
-                    qc_lampflat.avg_di,"Average counts","%g"));
+                    qc_lampflat.avg_di,"Average counts"));
     ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC SPECFLAT NCNTSSTD",
-                    qc_lampflat.std_di,"Stdev counts","%g"));
+                    qc_lampflat.std_di,"Stdev counts"));
     ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC SPECFLAT OFFFLUX",
                     qc_lampflat.avg_of,
-                    "Average flux off frames","%g"));
+                    "Average flux off frames"));
 
-    ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,
+    ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,
                     "QC LFLAT FPN1",
                     fpn_stdev1,
-                    "Fixed Pattern Noise of combined frames",
-                    "%f"));
+                    "Fixed Pattern Noise of combined frames"));
 
-    ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,
+    ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,
                     "QC LFLAT FPN2",
                     fpn_stdev2,
-                    "Fixed Pattern Noise of combined frames",
-                    "%f"));
+                    "Fixed Pattern Noise of combined frames"));
 
     ck0(sinfo_pro_save_ima(im_obj,ref_set,sof,cfg->outName,
                     PRO_MASTER_FLAT_LAMP,qclog_tbl,plugin_id,config),
@@ -757,19 +755,19 @@ sinfo_new_lamp_flats (const char* plugin_id,
         ck0(new_lamp_flats_det_ncounts(raw,cfg),"error computing ncounts");
         cknull_nomsg(qclog_tbl = sinfo_qclog_init());
         ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC SPECFLAT NCNTSAVG",
-                        qc_lampflat.avg_di,"Average counts","%g"));
+                        qc_lampflat.avg_di,"Average counts"));
 
         ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC SPECFLAT NCNTSSTD",
-                        qc_lampflat.std_di,"Stdev counts","%g"));
+                        qc_lampflat.std_di,"Stdev counts"));
 
         ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC SPECFLAT OFFFLUX",
-                        qc_lampflat.avg_of,"Average flux off frames","%g"));
+                        qc_lampflat.avg_of,"Average flux off frames"));
 
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC LFLAT FPN1",fpn_stdev1,
-                        "Fixed Pattern Noise of combined frames","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC LFLAT FPN1",fpn_stdev1,
+                        "Fixed Pattern Noise of combined frames"));
 
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC LFLAT FPN2",fpn_stdev2,
-                        "Fixed Pattern Noise of combined frames","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC LFLAT FPN2",fpn_stdev2,
+                        "Fixed Pattern Noise of combined frames"));
 
 
         ck0(sinfo_pro_save_ima(im_dither,ref_set,sof,outNameDither,
