@@ -401,8 +401,8 @@ sinfo_new_psf (const char* plugin_id,
         cknull_nomsg(qclog_tbl = sinfo_qclog_init());
         check_nomsg(sinfo_add_com_psf_qclog(fname1,&qclog_tbl));
         if(irplib_isnan(strehl1)) strehl1=-100.;
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC STREHL025",strehl1,
-                        "STREHL 25 mas","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC STREHL025",strehl1,
+                        "STREHL 25 mas"));
         ck0(sinfo_pro_save_ima(med_img1,ref_set,sof,PSF_MED_CUB_025_FILENAME,
                         PRO_MED_COADD_PSF,qclog_tbl,plugin_id,config),
             "cannot save ima %s", PSF_MED_CUB_100_FILENAME);
@@ -412,13 +412,13 @@ sinfo_new_psf (const char* plugin_id,
         cknull_nomsg(qclog_tbl = sinfo_qclog_init());
         check_nomsg(sinfo_add_com_psf_qclog(fname2,&qclog_tbl));
         if(irplib_isnan(strehl2)) strehl2=-100.;
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC STREHL100",strehl2,
-                        "STREHL 100 mas","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC STREHL100",strehl2,
+                        "STREHL 100 mas"));
 
         if(irplib_isnan(strehl)) strehl=-100.;
 
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC STREHL",strehl,
-                        "STREHL from both pixel scale images","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC STREHL",strehl,
+                        "STREHL from both pixel scale images"));
         ck0(sinfo_pro_save_ima(med_img2,ref_set,sof,PSF_MED_CUB_100_FILENAME,
                         PRO_MED_COADD_PSF,qclog_tbl,plugin_id,config),
             "cannot save ima %s", PSF_MED_CUB_100_FILENAME);
@@ -436,24 +436,24 @@ sinfo_new_psf (const char* plugin_id,
     if(strehl_sw==0) {
         if(irplib_isnan(strehl)) strehl=-100.;
 
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC STREHL",strehl,
-                        "STREHL from image","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC STREHL",strehl,
+                        "STREHL from image"));
 
     }
 
     check_nomsg(strehl=cpl_table_get_column_median(ao_performance,"strehl"));
 
-    ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC STREHL MED",strehl,
-                    "STREHL MEDIAN","%f"));
+    ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC STREHL MED",strehl,
+                    "STREHL MEDIAN"));
 
     check_nomsg(strehl=cpl_table_get_column_mean(ao_performance,"strehl"));
 
-    ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC STREHL AVG",strehl,
-                    "STREHL AVERAGE","%f"));
+    ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC STREHL AVG",strehl,
+                    "STREHL AVERAGE"));
     /*
   strehl=sinfo_get_strehl_from_ima(med_img1,frm1);
 
-  ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC STREHL AVG",strehl,
+  ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC STREHL AVG",strehl,
             "STREHL AVERAGE","%f"));
      */
     for(i=1;i<nsample;i++) {
@@ -463,26 +463,26 @@ sinfo_new_psf (const char* plugin_id,
         if(irplib_isnan(strehl)) strehl=-100.;
 
         snprintf(key_name,MAX_NAME_SIZE-1,"%s%d","QC STREHL",i);
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,strehl,"STREHL","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,key_name,strehl,"STREHL"));
 
         check_nomsg(lam=cpl_table_get_double(ao_performance,"wavelength",
                         i,&status));
         snprintf(key_name,MAX_NAME_SIZE-1,"%s%d","QC LAMBDA",i);
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,lam,
-                        "WAVELENGTH","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,key_name,lam,
+                        "WAVELENGTH"));
 
     }
 
     check_nomsg(strehl=cpl_table_get_column_median(ao_performance,
                     "strehl_error"));
-    ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC STREHL MEDERR",strehl,
-                    "STREHL ERROR MEDIAN","%f"));
+    ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC STREHL MEDERR",strehl,
+                    "STREHL ERROR MEDIAN"));
     ck0_nomsg(sinfo_qclog_add_string(qclog_tbl,"OBS NAME",obs_name1,
-                    "OB name","%s"));
+                    "OB name"));
     ck0_nomsg(sinfo_qclog_add_bool(qclog_tbl,PAF_NAME_LAMP_HALO,hlamp_st,
-                    KEY_NAME_LAMP_HALO,"%d"));
+                    KEY_NAME_LAMP_HALO));
     ck0_nomsg(sinfo_qclog_add_bool(qclog_tbl,PAF_NAME_SHUT2_ST,shut2_st,
-                    KEY_NAME_SHUT2_ST,"%d"));
+                    KEY_NAME_SHUT2_ST));
 
     ck0(sinfo_pro_save_tbl(ao_performance,ref_set,sof,
                     PSF_AO_PERFORMANCE_OUT_FILENAME,
@@ -510,14 +510,14 @@ sinfo_new_psf (const char* plugin_id,
 
     /* QC log */
     cknull_nomsg(qclog_tbl = sinfo_qclog_init());
-    ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC FWHMX",fwhm_x,
-                    "QC FWHM X","%f"));
-    ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC FWHMY",fwhm_y,
-                    "QC FWHM Y","%f"));
+    ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC FWHMX",fwhm_x,
+                    "QC FWHM X"));
+    ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC FWHMY",fwhm_y,
+                    "QC FWHM Y"));
     ck0_nomsg(sinfo_qclog_add_bool(qclog_tbl,PAF_NAME_LAMP_HALO,
-                    hlamp_st,KEY_NAME_LAMP_HALO,"%d"));
+                    hlamp_st,KEY_NAME_LAMP_HALO));
     ck0_nomsg(sinfo_qclog_add_bool(qclog_tbl,PAF_NAME_SHUT2_ST,shut2_st,
-                    KEY_NAME_SHUT2_ST,"%d"));
+                    KEY_NAME_SHUT2_ST));
 
     ck0(sinfo_pro_save_ima(med_img1,ref_set,sof,cfg->outName,PRO_PSF,
                     qclog_tbl,plugin_id,config),
@@ -562,7 +562,7 @@ sinfo_add_com_psf_qclog(const char* fname,cpl_table** qclog_tbl)
     if (cpl_propertylist_has(plist, KEY_NAME_LOOP_STATE)) {
         sinfo_qclog_add_string(*qclog_tbl,KEY_NAME_LOOP_STATE,
                         cpl_propertylist_get_string(plist,KEY_NAME_LOOP_STATE),
-                        KEY_HELP_LOOP_STATE,"%s");
+                        KEY_HELP_LOOP_STATE);
     }
 
 
@@ -570,14 +570,14 @@ sinfo_add_com_psf_qclog(const char* fname,cpl_table** qclog_tbl)
     if (cpl_propertylist_has(plist, KEY_NAME_LOOP_LGS)) {
         sinfo_qclog_add_int(*qclog_tbl,KEY_NAME_LOOP_LGS,
                         cpl_propertylist_get_int(plist,KEY_NAME_LOOP_LGS),
-                        KEY_HELP_LOOP_LGS,"%d");
+                        KEY_HELP_LOOP_LGS);
     }
 
 
     if (cpl_propertylist_has(plist, KEY_NAME_INS1_MODE)) {
         sinfo_qclog_add_string(*qclog_tbl,KEY_NAME_INS1_MODE,
                         cpl_propertylist_get_string(plist,KEY_NAME_INS1_MODE),
-                        KEY_HELP_INS1_MODE,"%s");
+                        KEY_HELP_INS1_MODE);
     }
 
 
@@ -1009,9 +1009,9 @@ cpl_table* sinfo_get_encircled_energy(cpl_frameset* sof,
     if(!isnan(flux) && !isnan(flux_max)) {
         enc_en=flux/flux_max;
     }
-    ck0_nomsg(sinfo_qclog_add_double(*qclog_tbl,"QC ENC CORE",
+    ck0_nomsg(sinfo_qclog_add_double_f(*qclog_tbl,"QC ENC CORE",
                     enc_en,
-                    "Encircled energy within PSF core","%f"));
+                    "Encircled energy within PSF core"));
     return enc_energy;
 
     cleanup:
