@@ -390,13 +390,13 @@ if (cfg->calibIndicator == 1 && cfg->wavemapInd == 0) {
     sinfo_det_ncounts(raw, cfg->qc_thresh_max,qc);
     qclog_tbl = sinfo_qclog_init();
     ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC WAVE ALL",
-                  n_lines,"Number of found lines","%d"));
+                  n_lines,"Number of found lines"));
 
     ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC WAVE NPIXSAT",
-                  qc->nsat,"Number of saturated pixels","%d"));
+                  qc->nsat,"Number of saturated pixels"));
 
     ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC WAVE MAXFLUX",
-                qc->max_di,"Max int off-lamp subracted frm","%g"));
+                qc->max_di,"Max int off-lamp subracted frm"));
 
    if(-1 == sinfo_pro_save_ima(map,raw,sof,cfg->outName,
          PRO_WAVE_MAP,qclog_tbl,cpl_func,config)) {
@@ -423,7 +423,7 @@ if (cfg->calibIndicator == 1 && cfg->wavemapInd == 0) {
          qclog_tbl = sinfo_qclog_init();
          key_name  = cpl_calloc(FILE_NAME_SZ,sizeof(char));
          ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC WAVE ALL",
-               n_lines,"Number of found lines","%d"));
+               n_lines,"Number of found lines"));
 
 
 
@@ -447,12 +447,12 @@ if (cfg->calibIndicator == 1 && cfg->wavemapInd == 0) {
             //trow=1+i;
             snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%s","QC COEF",i," AVG");
             ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,coef_avg,
-                         "Average wavecal Coef","%g"));
+                         "Average wavecal Coef"));
 
             //trow=1+i+cfg->nrDispCoefficients;
             snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%s","QC COEF",i," MED");
             ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,coef_med,
-                         "Median wavecal Coef","%g"));
+                         "Median wavecal Coef"));
 
      }
 
@@ -514,7 +514,7 @@ if (cfg->calibIndicator == 1 && cfg->wavemapInd == 0) {
 
     qclog_tbl = sinfo_qclog_init();
     ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC NLINES",n_found_lines,
-                  "Number of Found lines","%d"));
+                  "Number of Found lines"));
 
       for ( i = 0 ; i < par[0] -> n_params ; i++ )
       {
@@ -533,11 +533,11 @@ if (cfg->calibIndicator == 1 && cfg->wavemapInd == 0) {
 
       fwhm_avg = cpl_table_get_column_mean(tbl_fp,"fpar1");
       fwhm_med = cpl_table_get_column_median(tbl_fp,"fpar1");
-      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC FWHM MED",fwhm_med,
-                       "Median FWHM of found lines","%f"));
+      ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC FWHM MED",fwhm_med,
+                       "Median FWHM of found lines"));
 
-      ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC FWHM AVG",fwhm_avg,
-                       "Average FWHM of found lines","%f"));
+      ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC FWHM AVG",fwhm_avg,
+                       "Average FWHM of found lines"));
 
 
       if(-1 == sinfo_pro_save_tbl(tbl_fp,raw,sof,cfg->paramsList,
@@ -636,17 +636,17 @@ if (cfg->calibIndicator == 1 && cfg->wavemapInd == 0) {
     sinfo_det_ncounts(raw, cfg->qc_thresh_max,qc);
     qclog_tbl = sinfo_qclog_init();
     ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC NLINES",n_lines,
-                  "Number of found lines","%d"));
+                  "Number of found lines"));
 
 
 
     fwhm_avg = cpl_table_get_column_mean(tbl_fp,"fpar1");
     fwhm_med = cpl_table_get_column_median(tbl_fp,"fpar1");
 
-    ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC FWHM MED",fwhm_med,
-                     "Median FWHM of found lines","%f"));
-    ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC FWHM AVG",fwhm_avg,
-                     "Average FWHM of found lines","%f"));
+    ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC FWHM MED",fwhm_med,
+                     "Median FWHM of found lines"));
+    ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC FWHM AVG",fwhm_avg,
+                     "Average FWHM of found lines"));
 
 
     if(-1 == sinfo_pro_save_ima(map,raw,sof,cfg->outName,
