@@ -61,9 +61,18 @@ sinfo_new_stdstar (const char* plugin_id,
                    cpl_parameterlist* config,
                    cpl_frameset* sof,cpl_frameset* ref_set) ;
 
+cpl_mask * sinfo_bpm_filter(
+        const cpl_mask    *   input_mask,
+        cpl_size        kernel_nx,
+        cpl_size        kernel_ny,
+        cpl_filter_mode filter);
 
-
-
+cpl_image *
+sinfo_simple_extraction_from_cube(cpl_imagelist * cube,
+                                  const cpl_mask* obj_mask,
+                                  const char* name,
+                                  cpl_table** spectrum,
+                                  int qc_info);
 #endif /*!SINFO_STDSTAR_H*/
 
 /*--------------------------------------------------------------------------*/
