@@ -360,13 +360,13 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
 
         cknull_nomsg(qclog_tbl = sinfo_qclog_init());
         ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC WAVE ALL",n_lines,
-                        "Number of found lines","%d"));
+                        "Number of found lines"));
         ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC WAVE NPIXSAT",qc->nsat,
-                        "Number of saturated pixels","%d"));
+                        "Number of saturated pixels"));
         ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC WAVE MAXFLUX",qc->max_di,
-                        "Max int off-lamp subtracted frm","%g"));
+                        "Max int off-lamp subtracted frm"));
         ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC WAVE POSERR",shift,
-                        "Overall positioning error in mum","%g"));
+                        "Overall positioning error in mum"));
 
         ck0(sinfo_pro_save_ima(map_img,ref_set,sof,cfg->outName,
                         PRO_WAVE_MAP,qclog_tbl,plugin_id,config),
@@ -389,7 +389,7 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
 
             cknull_nomsg(qclog_tbl = sinfo_qclog_init());
             ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC WAVE ALL",n_lines,
-                            "Number found lines","%d"));
+                            "Number found lines"));
 
             for (j=0; j< lx; j++) {
                 for (i=0; i< cfg->nrDispCoefficients; i++) {
@@ -406,11 +406,11 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
 
                 snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%s","QC COEF",i," AVG");
                 ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,coef_avg,
-                                "Average wavecal Coef","%g"));
+                                "Average wavecal Coef"));
 
                 snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%s","QC COEF",i," MED");
                 ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,coef_med,
-                                "Median wavecal Coef","%g"));
+                                "Median wavecal Coef"));
 
             }
             if(pdensity >1) {
@@ -466,16 +466,16 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
             sinfo_msg("avg=%d",avg_lines);
 
             sinfo_qclog_add_int(qclog_tbl,"QC NLINES",avg_lines,
-                            "Average number of detected lines","%d");
+                            "Average number of detected lines");
             sinfo_qclog_add_int(qclog_tbl,"QC NLINES MIN",min_lines,
-                                       "Minimum number of detected lines","%d");
+                                       "Minimum number of detected lines");
             sinfo_qclog_add_int(qclog_tbl,"QC NLINES MAX",max_lines,
-                                       "Maximum number of detected lines","%d");
+                                       "Maximum number of detected lines");
 
             sinfo_qclog_add_int(qclog_tbl,"QC NLINES MIN POS",min_lines_col,
-                                        "Minimum number of detected lines","%d");
+                                        "Column with minimum number of detected lines");
             sinfo_qclog_add_int(qclog_tbl,"QC NLINES MAX POS",max_lines_col,
-                                        "Maximum number of detected lines","%d");
+                                        "Column with maximum number of detected lines");
 
             for ( i = 0 ; i < par[0] -> n_params ; i++ ) {
 
@@ -501,10 +501,10 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
 
             check_nomsg(fwhm_avg = cpl_table_get_column_mean(tbl_fp,"fpar1"));
             check_nomsg(fwhm_med = cpl_table_get_column_median(tbl_fp,"fpar1"));
-            ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC FWHM MED",fwhm_med,
-                            "Median FWHM of found lines","%f"));
-            ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC FWHM AVG",fwhm_avg,
-                            "Average FWHM of found lines","%f"));
+            ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC FWHM MED",fwhm_med,
+                            "Median FWHM of found lines"));
+            ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC FWHM AVG",fwhm_avg,
+                            "Average FWHM of found lines"));
 
             if(pdensity > 1) {
                 ck0(sinfo_pro_save_tbl(tbl_fp,ref_set,sof,cfg->paramsList,
@@ -583,15 +583,15 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
         cknull_nomsg(qclog_tbl = sinfo_qclog_init());
 
         ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC NLINES",n_lines,
-                        "Number of found lines","%d"));
+                        "Number of found lines"));
 
         check_nomsg(fwhm_avg = cpl_table_get_column_mean(tbl_fp,"fpar1"));
         check_nomsg(fwhm_med = cpl_table_get_column_median(tbl_fp,"fpar1"));
 
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC FWHM MED",fwhm_med,
-                        "Median FWHM of found lines","%f"));
-        ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,"QC FWHM AVG",fwhm_avg,
-                        "Average FWHM of found lines","%f"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC FWHM MED",fwhm_med,
+                        "Median FWHM of found lines"));
+        ck0_nomsg(sinfo_qclog_add_double_f(qclog_tbl,"QC FWHM AVG",fwhm_avg,
+                        "Average FWHM of found lines"));
 
         ck0(sinfo_pro_save_ima(map_img,ref_set,sof,cfg->outName,
                         PRO_WAVE_MAP,qclog_tbl,plugin_id,config),
