@@ -131,6 +131,27 @@ double sinfo_pfits_get_exptime(const char * filename)
     return exptime;
 }
 
+/*--------------------------------------------------------------------------- */
+/**
+  @brief    find out the GAIN value
+  @param    plist property list to read from
+  @return   the requested value
+*/
+/*--------------------------------------------------------------------------- */
+double sinfo_pfits_get_gain (const cpl_propertylist * plist)
+{
+
+  return cpl_propertylist_get_double(plist,SINFO_DET_GAIN);
+
+}
+
+
+double sinfo_pfits_get_airm_end (const cpl_propertylist * plist)
+{
+
+  return cpl_propertylist_get_double(plist,SINFO_AIRM_END);
+
+}
 
 
 
@@ -359,6 +380,18 @@ int sinfo_pfits_get_naxis3(const cpl_propertylist * plist)
     return cpl_propertylist_get_int(plist,"NAXIS3");
 }
 
+/*---------------------------------------------------------------------------*/
+/**
+  @brief    find out the character string associated to the CRPIX2 keyword
+  @param    plist    FITS header
+  @return   keyword value
+ */
+/*---------------------------------------------------------------------------*/
+double sinfo_pfits_get_crpix1(const cpl_propertylist * plist)
+{
+    return cpl_propertylist_get_double(plist,"CRPIX1");
+}
+
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the character string associated to the CRPIX2 keyword
@@ -372,7 +405,6 @@ double sinfo_pfits_get_crpix2(const cpl_propertylist * plist)
 }
 
 
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the character string associated to the CRPIX3 keyword
@@ -465,6 +497,24 @@ double sinfo_pfits_get_crval3(const cpl_propertylist * plist)
 }
 
 
+
+
+
+
+cpl_error_code
+sinfo_get_wcs_cube(const cpl_propertylist* plist, double *clambda,
+         double *dis, double *cpix, double *cx, double *cy)
+{
+
+  *clambda=sinfo_pfits_get_crval3(plist);
+  *dis=sinfo_pfits_get_cdelt3(plist);
+  *cpix=sinfo_pfits_get_crpix3(plist);
+  *cx=sinfo_pfits_get_crpix1(plist);
+  *cy=sinfo_pfits_get_crpix2(plist);
+
+  return cpl_error_get_code();
+
+}
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the RA keyword in a SINFONI header
@@ -560,5 +610,37 @@ sinfo_plist_set_extra_keys(cpl_propertylist* plist,
 
     return cpl_error_get_code();
 }
+/*--------------------------------------------------------------------------- */
+/**
+  @brief    find out the TEL AIRM START value
+  @param    plist property list to read from
+  @return   the requested value
+*/
+/*--------------------------------------------------------------------------- */
+double sinfo_pfits_get_airm_start (const cpl_propertylist * plist)
+{
+
+  return cpl_propertylist_get_double(plist,SINFO_AIRM_START);
+}
+
+
+
+/*--------------------------------------------------------------------------- */
+/**
+  @brief    find out the mean airmass value
+  @param    plist property list to read from
+  @return   the requested value
+*/
+/*--------------------------------------------------------------------------- */
+double sinfo_pfits_get_airm_mean (const cpl_propertylist * plist)
+{
+  double airmass_start=0;
+  double airmass_end=0;
+ airmass_start = sinfo_pfits_get_airm_start(plist);
+ airmass_end = sinfo_pfits_get_airm_end(plist);
+
+ return 0.5*(airmass_start+airmass_end);
+}
+
 
 /**@}*/
