@@ -40,11 +40,20 @@
 /*-----------------------------------------------------------------------------
                                    Functions prototypes
  -----------------------------------------------------------------------------*/
+#define SINFO_AIRM_START  "ESO TEL AIRM START"
+#define SINFO_AIRM_END    "ESO TEL AIRM END"
+#define SINFO_DET_GAIN "ESO DET OUT1 GAIN"
+#define SINFO_AIRM_START  "ESO TEL AIRM START"
+#define SINFO_AIRM_END    "ESO TEL AIRM END"
 
 CPL_BEGIN_DECLS
 float sinfo_pfits_get_pixelscale (const char * filename );
 double sinfo_pfits_get_targ_alpha(const cpl_propertylist * plist);
 double sinfo_pfits_get_targ_delta(const cpl_propertylist * plist);
+double sinfo_pfits_get_airm_mean (const cpl_propertylist * plist);
+double sinfo_pfits_get_gain (const cpl_propertylist * plist);
+double sinfo_pfits_get_airm_start (const cpl_propertylist * plist);
+double sinfo_pfits_get_airm_end (const cpl_propertylist * plist);
 
 /*
 char * sinfo_pfits_get_rec1raw1name(const char * filename) ;
@@ -80,12 +89,16 @@ double sinfo_pfits_get_crval1(const cpl_propertylist *) ;
 double sinfo_pfits_get_crval2(const cpl_propertylist *) ;
 double sinfo_pfits_get_crval3(const cpl_propertylist *) ;
 
+double sinfo_pfits_get_crpix1(const cpl_propertylist *) ;
 double sinfo_pfits_get_crpix2(const cpl_propertylist *) ;
 double sinfo_pfits_get_crpix3(const cpl_propertylist *) ;
 
 double sinfo_pfits_get_cdelt1(const cpl_propertylist *) ;
 double sinfo_pfits_get_cdelt2(const cpl_propertylist *) ;
 double sinfo_pfits_get_cdelt3(const cpl_propertylist *) ;
+cpl_error_code
+sinfo_get_wcs_cube(const cpl_propertylist* plist, double *clambda,
+         double *dis, double *cpix, double *cx, double *cy);
 
 cpl_error_code
 sinfo_plist_set_extra_keys(cpl_propertylist* plist,
