@@ -58,162 +58,184 @@ sinfo_clean_cube_header(cpl_propertylist** header);
  * TBD
  */
 
+
+
+/*---------------------------------------------------------------------------*/
 /**
-   @name sinfo_update_fits_card_int
-   @brief update an integer card in the header of a FITS file
-   @param file file name
-   @param card card name
-   @param value card value
-   @return if success 0 ; else -1
+   @brief    Save the table products on disk
+   @param    table    the input table
+   @param    ref      the reference frame set
+   @param    set      the output frame set
+   @param    out_file the output file name
+   @param    pro_catg the frame product category
+   @param    qclog    the table to store quality control parameters
+   @param    recid    the recipe id
+   @param    parlist  the recipe parameter list
+   @return   0 if everything is ok, -1 otherwise
  */
+/*---------------------------------------------------------------------------*/
+
+
+
+int sinfo_pro_save_tbl(
+                cpl_table       *   table,
+                cpl_frameset    *   ref,
+                cpl_frameset    *   set,
+                const char      *   out_file,
+                const char      *   pro_catg,
+                cpl_table       *   qclog,
+                const char      *   recid,
+                cpl_parameterlist* parlist)
 
-int 
-sinfo_update_fits_card_int(const char* file,const char* card,int value)
 {
-    cpl_propertylist *   plist =NULL;
-    if ((plist = cpl_propertylist_load(file, 0)) == NULL) {
-        sinfo_msg_error( "getting header from file %s",file);
+    char *    name_o =NULL;
+    char *    name_p =NULL;
+    cpl_propertylist *   plist=NULL ;
+    char* ref_file=NULL;
+    /* Get the reference file  */
+
+    cpl_frameset_iterator* it = cpl_frameset_iterator_new(ref);
+    cpl_frame *first_frame = cpl_frameset_iterator_get(it);
+    ref_file = cpl_strdup(cpl_frame_get_filename(first_frame)) ;
+
+    name_o = cpl_malloc(FILE_NAME_SZ * sizeof(char));
+    name_p = cpl_malloc(FILE_NAME_SZ * sizeof(char));
+    sinfo_check_name(out_file, &name_o, CPL_FRAME_TYPE_TABLE, &name_p);
+    sinfo_msg( "Writing tbl %s pro catg %s" , name_o, pro_catg) ;
+
+    /* Get FITS header from reference file */
+    if ((cpl_error_code)((plist = cpl_propertylist_load(ref_file,0)) == NULL))
+    {
+        sinfo_msg_error( "getting header from tbl frame %s",ref_file);
         cpl_propertylist_delete(plist) ;
+        cpl_free(ref_file);
+        cpl_free(name_o);
+        cpl_free(name_p);
+        cpl_frameset_iterator_delete(it);
+        return -1 ;
+    }
+    sinfo_clean_header(&plist);
+
+    /* Add DataFlow keywords and log the saved file in the input frameset */
+    sinfo_log_pro(name_o, pro_catg, CPL_FRAME_TYPE_TABLE,
+                  ref,&set,&plist,parlist,recid);
+    if(qclog != NULL) {
+        sinfo_pfits_put_qc(plist, qclog) ;
+    }
+    /* Save the file */
+    if (cpl_table_save(table, plist, NULL, name_o, CPL_IO_DEFAULT)
+                    != CPL_ERROR_NONE) {
+        sinfo_msg_error( "Cannot save the product: %s", name_o);
+        cpl_propertylist_delete(plist) ;
+        cpl_free(ref_file);
+        cpl_free(name_o);
+        cpl_free(name_p);
+        cpl_frameset_iterator_delete(it);
         return -1 ;
     }
 
-    if (CPL_ERROR_NONE!=cpl_propertylist_set_int(plist,card,value)){
-        sinfo_msg_error( "setting header of file %s",file);
-        cpl_propertylist_delete(plist) ;
-        return -1 ;
-    }
     cpl_propertylist_delete(plist) ;
-    return 0;
+    cpl_msg_indent_less() ;
+    cpl_free(name_o);
+    cpl_free(name_p);
+    cpl_free(ref_file);
+    cpl_frameset_iterator_delete(it);
+    return 0 ;
 }
-
+/*---------------------------------------------------------------------------*/
 /**
-   @name sinfo_update_fits_card_float
-   @brief update a float card in the header of a FITS file
-   @param file file name
-   @param card card name
-   @param value card value
-   @return if success 0 ; else -1
+   @brief    Save the imagelist product on disk
+   @param    ims      the input imagelist
+   @param    ref      the reference frame set
+   @param    set      the output frame set
+   @param    out_file the output file name
+   @param    pro_catg the frame product category
+   @param    qclog    the table to store quality control parameters
+   @param    recid    the recipe id
+   @param    parlist  the recipe parameter list
+   @return   0 if everything is ok, -1 otherwise
  */
+/*---------------------------------------------------------------------------*/
+
+
+
+int sinfo_pro_save_ims(
+                cpl_imagelist   *   ims,
+                cpl_frameset    *   ref,
+                cpl_frameset    *   set,
+                const char      *   out_file,
+                const char      *   pro_catg,
+                cpl_table       *   qclog,
+                const char      *   recid,
+                cpl_parameterlist* parlist)
 
-int 
-sinfo_update_fits_card_float(const char* file,const char* card,float value)
 {
-    cpl_propertylist *   plist =NULL;
-    if ((plist = cpl_propertylist_load(file, 0)) == NULL) {
-        sinfo_msg_error( "getting header from file %s",file);
-        sinfo_msg_error("%s", (char* ) cpl_error_get_message());
-        sinfo_msg_error("%s", (char* ) cpl_error_get_where());
+    char *               name_o=NULL;
+    char *               name_p=NULL;
+
+    cpl_propertylist * plist=NULL ;
+    char* ref_file=NULL;
+
+    /* Get the reference file  */
+    cpl_frameset_iterator* it = cpl_frameset_iterator_new(ref);
+    cpl_frame *first_frame = cpl_frameset_iterator_get(it);
+
+    ref_file = cpl_strdup(cpl_frame_get_filename(first_frame)) ;
+
+    name_o = cpl_malloc(FILE_NAME_SZ * sizeof(char));
+    name_p = cpl_malloc(FILE_NAME_SZ * sizeof(char));
+    sinfo_check_name(out_file, &name_o, CPL_FRAME_TYPE_IMAGE, &name_p);
+    sinfo_msg( "Writing ims %s pro catg %s" , name_o, pro_catg) ;
+    /* Get FITS header from reference file */
+    if ((cpl_error_code)((plist = cpl_propertylist_load(ref_file, 0)) == NULL))
+    {
+        sinfo_msg_error( "getting header from ims frame %s",ref_file);
         cpl_propertylist_delete(plist) ;
+        cpl_free(ref_file);
+        cpl_free(name_o);
+        cpl_free(name_p);
+        cpl_frameset_iterator_delete(it);
         return -1 ;
     }
-
-    if (CPL_ERROR_NONE!=cpl_propertylist_set_float(plist,card,value)){
-        sinfo_msg_error( "setting header of file %s",file);
-        sinfo_msg_error("%s", (char* ) cpl_error_get_message());
-        sinfo_msg_error("%s", (char* ) cpl_error_get_where());
-        cpl_propertylist_delete(plist) ;
-        return -1 ;
-    }
-    cpl_propertylist_delete(plist) ;
-    return 0;
-}
-
-
-/**
-   @name sinfo_update_fits_card_double
-   @brief update a double card in the header of a FITS file
-   @param file file name
-   @param card card name
-   @param value card value
-   @return if success 0 ; else -1
- */
-
-int 
-sinfo_update_fits_card_double(const char* file,const char* card,double value)
-{
-    cpl_propertylist *   plist =NULL;
-    if ((plist = cpl_propertylist_load(file, 0)) == NULL) {
-        sinfo_msg_error( "getting header from file %s",file);
-        cpl_propertylist_delete(plist) ;
-        return -1 ;
+    sinfo_clean_header(&plist);
+    if ( ( strstr(pro_catg,"STD") != NULL ) ||
+                    ( strstr(pro_catg,"PSF") != NULL ) ||
+                    ( strstr(pro_catg,"OBJ") != NULL ) ) {
+        sinfo_clean_cube_header(&plist);
     }
 
-    if (CPL_ERROR_NONE!=cpl_propertylist_set_double(plist,card,value)){
-        sinfo_msg_error( "gsetting header of file %s",file);
-        cpl_propertylist_delete(plist) ;
-        return -1 ;
-    }
-    cpl_propertylist_delete(plist) ;
-    return 0;
-}
+    /* Add DataFlow keywords and log the saved file in the input frameset */
+    sinfo_log_pro(name_o, pro_catg, CPL_FRAME_TYPE_IMAGE,
+                  ref,&set,&plist,parlist,recid);
 
-/**
-   @name sinfo_update_fits_card_long
-   @brief update a long card in the header of a FITS file
-   @param file file name
-   @param card card name
-   @param value card value
-   @return if success 0 ; else -1
- */
-
-int 
-sinfo_update_fits_card_long(const char* file,const char* card,long value)
-{
-    cpl_propertylist *   plist =NULL;
-    if ((plist = cpl_propertylist_load(file, 0)) == NULL) {
-        sinfo_msg_error( "getting header from file %s",file);
-        cpl_propertylist_delete(plist) ;
-        return -1 ;
-    }
-    if (CPL_ERROR_NONE!=cpl_propertylist_set_long(plist,card,value)){
-        sinfo_msg_error( "setting header of file %s",file);
-        cpl_propertylist_delete(plist) ;
-        return -1 ;
-    }
-    cpl_propertylist_delete(plist) ;
-    return 0;
-}
-
-/**
-   @name sinfo_update_fits_card_string
-   @brief update a string card in the header of a FITS file
-   @param file file name
-   @param card card name
-   @param value card value
-   @return if success 0 ; else -1
- */
-
-int 
-sinfo_update_ims_fits_card_string(cpl_imagelist* iml,
-                                  const char* file, 
-                                  const char* card,
-                                  const char* value)
-{
-
-    cpl_propertylist *   plist =NULL;
-    if ((plist = cpl_propertylist_load(file, 0)) == NULL) {
-        sinfo_msg_error( "getting header from reference ima frame %s",file);
-        cpl_propertylist_delete(plist) ;
-        return -1 ;
+    if(qclog != NULL) {
+        sinfo_pfits_put_qc(plist, qclog) ;
     }
 
 
-    if (CPL_ERROR_NONE!=cpl_propertylist_set_string(plist,card,value)){
-        sinfo_msg_error( "getting header from reference ima frame %s",file);
-        cpl_propertylist_delete(plist) ;
-        return -1 ;
-    }
-
-    if (cpl_imagelist_save(iml,file,CPL_BPP_IEEE_FLOAT,
+    /* Save the file */
+    if (cpl_imagelist_save(ims, name_o, CPL_BPP_IEEE_FLOAT,
                     plist,CPL_IO_DEFAULT)!=CPL_ERROR_NONE) {
-        sinfo_msg_error( "getting header from reference ima frame %s",file);
+        sinfo_msg_error( "Cannot save the product %s",name_o);
         cpl_propertylist_delete(plist) ;
+        cpl_free(ref_file);
+        cpl_free(name_o);
+        cpl_free(name_p);
+        cpl_frameset_iterator_delete(it);
         return -1 ;
     }
+
     cpl_propertylist_delete(plist) ;
-    return 0;
+    cpl_msg_indent_less() ;
+    cpl_free(name_o);
+    cpl_free(name_p);
+    cpl_free(ref_file);
+    cpl_frameset_iterator_delete(it);
+    return 0 ;
 }
 
+
+
 /*---------------------------------------------------------------------------*/
 /**
    @brief    Save the image product on disk
@@ -304,186 +326,6 @@ int sinfo_pro_save_ima(
     return 0 ;
 }
 
-
-/*---------------------------------------------------------------------------*/
-/**
-   @brief    Save the table products on disk
-   @param    table    the input table 
-   @param    ref      the reference frame set 
-   @param    set      the output frame set
-   @param    out_file the output file name
-   @param    pro_catg the frame product category
-   @param    qclog    the table to store quality control parameters
-   @param    recid    the recipe id
-   @param    parlist  the recipe parameter list
-   @return   0 if everything is ok, -1 otherwise
- */
-/*---------------------------------------------------------------------------*/
-
-
-
-int sinfo_pro_save_tbl(
-                cpl_table       *   table,
-                cpl_frameset    *   ref,
-                cpl_frameset    *   set,
-                const char      *   out_file,
-                const char      *   pro_catg,
-                cpl_table       *   qclog,
-                const char      *   recid,
-                cpl_parameterlist* parlist)
-
-{
-    char *    name_o =NULL;
-    char *    name_p =NULL;
-    cpl_propertylist *   plist=NULL ;
-    char* ref_file=NULL;
-    /* Get the reference file  */
-
-    cpl_frameset_iterator* it = cpl_frameset_iterator_new(ref);
-    cpl_frame *first_frame = cpl_frameset_iterator_get(it);
-    ref_file = cpl_strdup(cpl_frame_get_filename(first_frame)) ;
-
-    name_o = cpl_malloc(FILE_NAME_SZ * sizeof(char));
-    name_p = cpl_malloc(FILE_NAME_SZ * sizeof(char));
-    sinfo_check_name(out_file, &name_o, CPL_FRAME_TYPE_TABLE, &name_p);
-    sinfo_msg( "Writing tbl %s pro catg %s" , name_o, pro_catg) ;
-
-    /* Get FITS header from reference file */
-    if ((cpl_error_code)((plist = cpl_propertylist_load(ref_file,0)) == NULL))
-    {
-        sinfo_msg_error( "getting header from tbl frame %s",ref_file);
-        cpl_propertylist_delete(plist) ;
-        cpl_free(ref_file);
-        cpl_free(name_o);
-        cpl_free(name_p);
-        cpl_frameset_iterator_delete(it);
-        return -1 ;
-    }
-    sinfo_clean_header(&plist);
-
-    /* Add DataFlow keywords and log the saved file in the input frameset */
-    sinfo_log_pro(name_o, pro_catg, CPL_FRAME_TYPE_TABLE,
-                  ref,&set,&plist,parlist,recid);
-    if(qclog != NULL) {
-        sinfo_pfits_put_qc(plist, qclog) ;
-    }
-    /* Save the file */
-    if (cpl_table_save(table, plist, NULL, name_o, CPL_IO_DEFAULT)
-                    != CPL_ERROR_NONE) {
-        sinfo_msg_error( "Cannot save the product: %s", name_o);
-        cpl_propertylist_delete(plist) ;
-        cpl_free(ref_file);
-        cpl_free(name_o);
-        cpl_free(name_p);
-        cpl_frameset_iterator_delete(it);
-        return -1 ;
-    }
-
-    cpl_propertylist_delete(plist) ;
-    cpl_msg_indent_less() ;
-    cpl_free(name_o);
-    cpl_free(name_p);
-    cpl_free(ref_file);
-    cpl_frameset_iterator_delete(it);
-    return 0 ;
-}
-
-
-
-/*---------------------------------------------------------------------------*/
-/**
-   @brief    Save the imagelist product on disk
-   @param    ims      the input imagelist 
-   @param    ref      the reference frame set 
-   @param    set      the output frame set
-   @param    out_file the output file name
-   @param    pro_catg the frame product category
-   @param    qclog    the table to store quality control parameters
-   @param    recid    the recipe id
-   @param    parlist  the recipe parameter list
-   @return   0 if everything is ok, -1 otherwise
- */
-/*---------------------------------------------------------------------------*/
-
-
-
-int sinfo_pro_save_ims(
-                cpl_imagelist   *   ims,
-                cpl_frameset    *   ref,
-                cpl_frameset    *   set,
-                const char      *   out_file,
-                const char      *   pro_catg,
-                cpl_table       *   qclog,
-                const char      *   recid,
-                cpl_parameterlist* parlist)
-
-{
-    char *               name_o=NULL;
-    char *               name_p=NULL;
-
-    cpl_propertylist * plist=NULL ;
-    char* ref_file=NULL;
-
-    /* Get the reference file  */
-    cpl_frameset_iterator* it = cpl_frameset_iterator_new(ref);
-    cpl_frame *first_frame = cpl_frameset_iterator_get(it);
-
-    ref_file = cpl_strdup(cpl_frame_get_filename(first_frame)) ;
-
-    name_o = cpl_malloc(FILE_NAME_SZ * sizeof(char));
-    name_p = cpl_malloc(FILE_NAME_SZ * sizeof(char));
-    sinfo_check_name(out_file, &name_o, CPL_FRAME_TYPE_IMAGE, &name_p);
-    sinfo_msg( "Writing ims %s pro catg %s" , name_o, pro_catg) ;
-    /* Get FITS header from reference file */
-    if ((cpl_error_code)((plist = cpl_propertylist_load(ref_file, 0)) == NULL))
-    {
-        sinfo_msg_error( "getting header from ims frame %s",ref_file);
-        cpl_propertylist_delete(plist) ;
-        cpl_free(ref_file);
-        cpl_free(name_o);
-        cpl_free(name_p);
-        cpl_frameset_iterator_delete(it);
-        return -1 ;
-    }
-    sinfo_clean_header(&plist);
-    if ( ( strstr(pro_catg,"STD") != NULL ) ||
-                    ( strstr(pro_catg,"PSF") != NULL ) ||
-                    ( strstr(pro_catg,"OBJ") != NULL ) ) {
-        sinfo_clean_cube_header(&plist);
-    }
-
-    /* Add DataFlow keywords and log the saved file in the input frameset */
-    sinfo_log_pro(name_o, pro_catg, CPL_FRAME_TYPE_IMAGE,
-                  ref,&set,&plist,parlist,recid);
-
-    if(qclog != NULL) {
-        sinfo_pfits_put_qc(plist, qclog) ;
-    }
-
-
-    /* Save the file */
-    if (cpl_imagelist_save(ims, name_o, CPL_BPP_IEEE_FLOAT,
-                    plist,CPL_IO_DEFAULT)!=CPL_ERROR_NONE) {
-        sinfo_msg_error( "Cannot save the product %s",name_o);
-        cpl_propertylist_delete(plist) ;
-        cpl_free(ref_file);
-        cpl_free(name_o);
-        cpl_free(name_p);
-        cpl_frameset_iterator_delete(it);
-        return -1 ;
-    }
-
-    cpl_propertylist_delete(plist) ;
-    cpl_msg_indent_less() ;
-    cpl_free(name_o);
-    cpl_free(name_p);
-    cpl_free(ref_file);
-    cpl_frameset_iterator_delete(it);
-    return 0 ;
-}
-
-
-
 static void
 sinfo_log_pro(char* name_o, 
               const char* pro_catg, 
@@ -661,15 +503,14 @@ int
 sinfo_qclog_add_int(cpl_table* table,
                     const char*  key_name,
                     const int    value,
-                    const char*  key_help,
-                    const char*  format)
+                    const char*  key_help)
 {
     int sz = cpl_table_get_nrow(table);
     int raw = sz;
     char key_value[FILE_NAME_SZ];
     char key_type[FILE_NAME_SZ];
 
-    snprintf(key_value,MAX_NAME_SIZE-1,format,value);
+    snprintf(key_value,MAX_NAME_SIZE-1,"%d",value);
     strcpy(key_type,"CPL_TYPE_INT");
 
     cpl_table_set_size(table,sz+1);
@@ -689,15 +530,14 @@ int
 sinfo_qclog_add_bool(cpl_table* table,
                      const char*  key_name,
                      const char   value,
-                     const char*  key_help,
-                     const char*  format)
+                     const char*  key_help)
 {
     int sz = cpl_table_get_nrow(table);
     int raw = sz;
     char key_value[FILE_NAME_SZ];
     char key_type[FILE_NAME_SZ];
 
-    snprintf(key_value,MAX_NAME_SIZE-1,format,value);
+    snprintf(key_value,MAX_NAME_SIZE-1,"%d",value);
     strcpy(key_type,"CPL_TYPE_BOOL");
 
     cpl_table_set_size(table,sz+1);
@@ -712,21 +552,19 @@ sinfo_qclog_add_bool(cpl_table* table,
 }
 
 
-
 int
-sinfo_qclog_add_float(cpl_table* table,
-                      const char*  key_name,
-                      const float  value,
-                      const char*  key_help,
-                      const char*  format)
+sinfo_qclog_add_double(cpl_table* table,
+                       const char*  key_name,
+                       const double value,
+                       const char*  key_help)
 {
     int sz = cpl_table_get_nrow(table);
     int raw = sz;
     char key_value[FILE_NAME_SZ];
     char key_type[FILE_NAME_SZ];
 
-    snprintf(key_value,MAX_NAME_SIZE-1,format,value);
-    strcpy(key_type,"CPL_TYPE_FLOAT");
+    snprintf(key_value,MAX_NAME_SIZE-1,"%g",value);
+    strcpy(key_type,"CPL_TYPE_DOUBLE");
 
     cpl_table_set_size(table,sz+1);
 
@@ -739,21 +577,43 @@ sinfo_qclog_add_float(cpl_table* table,
 
 }
 
-
-
 int
-sinfo_qclog_add_double(cpl_table* table,
+sinfo_qclog_add_double_f(cpl_table* table,
                        const char*  key_name,
                        const double value,
-                       const char*  key_help,
-                       const char*  format)
+                       const char*  key_help)
 {
     int sz = cpl_table_get_nrow(table);
     int raw = sz;
     char key_value[FILE_NAME_SZ];
     char key_type[FILE_NAME_SZ];
 
-    snprintf(key_value,MAX_NAME_SIZE-1,format,value);
+    snprintf(key_value,MAX_NAME_SIZE-1,"%f",value);
+    strcpy(key_type,"CPL_TYPE_DOUBLE");
+
+    cpl_table_set_size(table,sz+1);
+
+    cpl_table_set_string(table,"key_name" ,raw,key_name);
+    cpl_table_set_string(table,"key_type" ,raw,key_type);
+    cpl_table_set_string(table,"key_value",raw,key_value);
+    cpl_table_set_string(table,"key_help" ,raw,key_help);
+
+    return 0;
+
+}
+
+int
+sinfo_qclog_add_double_format(cpl_table* table,
+                       const char*  key_name,
+                       const double value,
+                       const char*  key_help)
+{
+    int sz = cpl_table_get_nrow(table);
+    int raw = sz;
+    char key_value[FILE_NAME_SZ];
+    char key_type[FILE_NAME_SZ];
+
+    snprintf(key_value,MAX_NAME_SIZE-1,"%13.6f",value);
     strcpy(key_type,"CPL_TYPE_DOUBLE");
 
     cpl_table_set_size(table,sz+1);
@@ -771,15 +631,14 @@ int
 sinfo_qclog_add_string(cpl_table* table,
                        const char*  key_name,
                        const char*  value,
-                       const char*  key_help,
-                       const char*  format)
+                       const char*  key_help)
 {
     int sz = cpl_table_get_nrow(table);
     int raw = sz;
     char key_value[FILE_NAME_SZ];
     char key_type[FILE_NAME_SZ];
 
-    snprintf(key_value,MAX_NAME_SIZE-1,format,value);
+    snprintf(key_value,MAX_NAME_SIZE-1,"%s",value);
     strcpy(key_type,"CPL_TYPE_STRING");
 
     cpl_table_set_size(table,sz+1);
