@@ -147,6 +147,7 @@ CPL_BEGIN_DECLS
 #define PRO_FOCUS_GAUSS                    "FOCUS_GAUSS"
 #define PRO_WAVE_MAP                       "WAVE_MAP"
 #define PRO_STD_STAR_SPECTRA               "STD_STAR_SPECTRA"
+#define PRO_STD_STAR_SPECTRA_FLUXCAL       "STD_STAR_SPECTRA_FLUXCAL"
 #define PRO_STD_STAR_SPECTRUM              "STD_STAR_SPECTRUM"
 
 #define PRO_CUBE                           "CUBE"
@@ -158,6 +159,13 @@ CPL_BEGIN_DECLS
 #define PRO_COADD_OBJ                      "COADD_OBJ"
 #define PRO_COADD_PUPIL                    "COADD_PUPIL"
 
+
+
+#define PRO_COADD_SKY_FLUXCAL              "COADD_SKY_FLUXCAL"
+#define PRO_COADD_PSF_FLUXCAL              "COADD_PSF_FLUXCAL"
+#define PRO_COADD_STD_FLUXCAL              "COADD_STD_FLUXCAL"
+#define PRO_COADD_OBJ_FLUXCAL              "COADD_OBJ_FLUXCAL"
+
 #define PRO_OBS_PSF                        "OBS_PSF"
 #define PRO_OBS_STD                        "OBS_STD"
 #define PRO_OBS_OBJ                        "OBS_OBJ"
@@ -187,5 +195,6 @@ CPL_BEGIN_DECLS
 #define PRO_OBJ_CUBE                       "OBJ_CUBE"
 #define PRO_BP_COEFF                       "BP_COEFF"
 #define PRO_EFFICIENCY                     "EFFICIENCY"
+#define PRO_RESPONSE                       "RESPONSE"
 CPL_END_DECLS
 #endif
