@@ -568,7 +568,6 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
     char outname[FILE_NAME_SZ];
     char filename[FILE_NAME_SZ];
 
-
     cpl_frameset * obj_set=NULL;
     cpl_frameset * sky_set=NULL;
     cpl_frameset * cdb_set=NULL;
@@ -606,7 +605,6 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
     cknull(obj_frm = cpl_frameset_get_frame(obj_set,0),
            "No object frames in input set.");
 
-
     strcpy(tag,cpl_frame_get_tag(obj_frm));
     if(NULL!=sinfo_new_set_obj_procatg(tag)){
         *pro_ctg_cube=sinfo_new_set_obj_procatg(tag);
@@ -615,7 +613,6 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
         goto cleanup;
     }
 
-
     if(NULL!=sinfo_new_set_stk_procatg(tag)){
         strcpy(pro_ctg_stack,sinfo_new_set_stk_procatg(tag));
     } else {
@@ -632,84 +629,72 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
         goto cleanup;
     }
 
-
     if ( (nobj != 0) && (nsky != 0) ) {
         /* We have either OBJ and SKY: we need to create OBJ-SKY pairs */
         sinfo_msg("------------------------------") ;
         sinfo_msg("Generates OBJ-SKY pairs");
         sinfo_msg("------------------------------") ;
 
-        check_nomsg(tot_set=cpl_frameset_new());
-        check_nomsg(p = cpl_parameterlist_find(config,
-                        "sinfoni.objnod.autojitter_method"));
-        check_nomsg(cpl_parameter_set_int(p,0));
+        tot_set=cpl_frameset_new();
+        p = cpl_parameterlist_find(config,
+                        "sinfoni.objnod.autojitter_method");
+        cpl_parameter_set_int(p,0);
 
         for (i=0;i<nobj;i++) {
 
-            cknull_nomsg(wrk_set=cpl_frameset_new());
-            check_nomsg(obj_frm=cpl_frameset_get_frame(obj_set,i));
+            wrk_set=cpl_frameset_new();
+            obj_frm=cpl_frameset_get_frame(obj_set,i);
             mjd_obj=sinfo_get_mjd_obs(obj_frm);
-            check_nomsg(sky_frm=cpl_frameset_get_frame(sky_set,0));
+            sky_frm=cpl_frameset_get_frame(sky_set,0);
             mjd_sky=sinfo_get_mjd_obs(sky_frm);
             strcpy(filename,cpl_frame_get_filename(obj_frm));
 
-
             for (j=1;j<nsky;j++) {
                 mjd_sky_frm = sinfo_get_mjd_obs(cpl_frameset_get_frame(sky_set,j));
                 if(1000.*(mjd_sky_frm-mjd_obj)*(mjd_sky_frm-mjd_obj) <
                                 1000.*(mjd_sky-    mjd_obj)*(mjd_sky-    mjd_obj) ) {
                     mjd_sky=mjd_sky_frm;
-                    check_nomsg(sky_frm=cpl_frameset_get_frame(sky_set,j));
+                    sky_frm=cpl_frameset_get_frame(sky_set,j);
                 }
             }
             strcpy(filename,cpl_frame_get_filename(sky_frm));
 
-
-
             /* monitors whih obj-sky frames are inserted in each wrk_set */
-            cknull_nomsg(dup_frm=cpl_frame_duplicate(obj_frm));
-            check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
-            cknull_nomsg(dup_frm=cpl_frame_duplicate(sky_frm));
-            check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
+            dup_frm=cpl_frame_duplicate(obj_frm);
+            cpl_frameset_insert(wrk_set,dup_frm);
+            dup_frm=cpl_frame_duplicate(sky_frm);
+            cpl_frameset_insert(wrk_set,dup_frm);
 
             /* merged CDB frames to work set */
             for(k=0;k<ncdb;k++) {
-                check_nomsg(cdb_frm=cpl_frameset_get_frame(cdb_set,k));
-                check_nomsg(dup_frm=cpl_frame_duplicate(cdb_frm));
-                check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
+                cdb_frm=cpl_frameset_get_frame(cdb_set,k);
+                dup_frm=cpl_frame_duplicate(cdb_frm);
+                cpl_frameset_insert(wrk_set,dup_frm);
             }
 
-
             /* defines a new name for the output stacked frame */
             snprintf(outname,MAX_NAME_SIZE-1,"%s%d%s","out_stack",i,".fits");
-            ck0(sinfo_new_stack_frames(config,wrk_set,pro_ctg_stack,i,fk,recipe_id),
-                "Cannot stack frames");
+            sinfo_new_stack_frames(config,wrk_set,pro_ctg_stack,i,fk,recipe_id);
 
             /* cube generation */
-            ck0( ( ind=sinfo_new_cubes_build(recipe_id,config,wrk_set,
-                            *pro_ctg_cube,i) ) ,
-                "GENERATING CUBE no. %d\n", ind) ;
+            ind=sinfo_new_cubes_build(recipe_id,config,wrk_set,*pro_ctg_cube,i);
 
-            check_nomsg(sinfo_extract_frames_group_type(wrk_set,
-                            &pro_set,
-                            CPL_FRAME_GROUP_PRODUCT));
-            check_nomsg(cpl_frameset_join(tot_set,pro_set));
+            sinfo_extract_frames_group_type(wrk_set,&pro_set,
+                                            CPL_FRAME_GROUP_PRODUCT);
+            cpl_frameset_join(tot_set,pro_set);
             sinfo_free_frameset(&pro_set);
             sinfo_free_frameset(&wrk_set);
 
-
         }
 
-        check_nomsg(sinfo_extract_frames_group_type(tot_set,
-                        &pro_set,
-                        CPL_FRAME_GROUP_PRODUCT));
-        check_nomsg(cpl_frameset_join(*set,pro_set));
+        sinfo_extract_frames_group_type(tot_set,&pro_set,
+                                        CPL_FRAME_GROUP_PRODUCT);
+        cpl_frameset_join(*set,pro_set);
         sinfo_free_frameset(&pro_set);
         sinfo_free_frameset(&tot_set);
 
     }
 
-
     if ( (nobj == 0) && (nsky != 0) ) {
 
         /* ===============================================================
@@ -723,23 +708,17 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
             goto cleanup;
         }
 
-
     }
 
-
-
     if ( (nobj != 0) && (nsky == 0) ) {
 
         /* ===============================================================
         OBJ FRAMES STACKING
         =============================================================== */
-        check_nomsg(p=cpl_parameterlist_find(config,
-                        "sinfoni.objnod.autojitter_method"));
-        check_nomsg(aj_meth =  cpl_parameter_get_int(p));
+        p=cpl_parameterlist_find(config,"sinfoni.objnod.autojitter_method");
+        aj_meth =  cpl_parameter_get_int(p);
         if(strcmp(pro_ctg_stack,PRO_PUPIL_LAMP_STACKED) == 0) {
-
             aj_meth = 0;
-
         }
 
         if(aj_meth == 2) {
@@ -757,79 +736,65 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
             sinfo_msg("Generates OBJ-SKY pairs");
             sinfo_msg("------------------------------") ;
 
-            check_nomsg(tot_set=cpl_frameset_new());
-
+            tot_set=cpl_frameset_new();
 
             for (i=0;i<nobj;i++) {
 
-                check_nomsg(wrk_set=cpl_frameset_new());
-                check_nomsg(obj_frm=cpl_frameset_get_frame(obj_set,i));
-                check_nomsg(dup_frm=cpl_frame_duplicate(obj_frm));
-                check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
-                check_nomsg(dup_frm=cpl_frame_duplicate(sky_frm));
-                check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
+                wrk_set=cpl_frameset_new();
+                obj_frm=cpl_frameset_get_frame(obj_set,i);
+                dup_frm=cpl_frame_duplicate(obj_frm);
+                cpl_frameset_insert(wrk_set,dup_frm);
+                dup_frm=cpl_frame_duplicate(sky_frm);
+                cpl_frameset_insert(wrk_set,dup_frm);
                 for(k=0;k<ncdb;k++) {
-                    check_nomsg(cdb_frm=cpl_frameset_get_frame(cdb_set,k));
-                    check_nomsg(dup_frm=cpl_frame_duplicate(cdb_frm));
-                    check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
+                    cdb_frm=cpl_frameset_get_frame(cdb_set,k);
+                    dup_frm=cpl_frame_duplicate(cdb_frm);
+                    cpl_frameset_insert(wrk_set,dup_frm);
                 }
 
                 snprintf(outname,MAX_NAME_SIZE-1,"%s%d%s","out_stack",i,".fits");
-                ck0(sinfo_new_stack_frames(config,wrk_set,pro_ctg_stack,
-                                i,fk,recipe_id),"Error Stacking frame %d",i);
-
+                sinfo_new_stack_frames(config,wrk_set,pro_ctg_stack,i,fk,recipe_id);
 
                 /* cube generation */
-                ck0( ( ind = sinfo_new_cubes_build(recipe_id,config,wrk_set,
-                                *pro_ctg_cube,i) ),
-                    "Error GENERATING CUBE no. %d\n", ind) ;
+                ind = sinfo_new_cubes_build(recipe_id,config,wrk_set,
+                                *pro_ctg_cube,i);
 
-
-
-
-                check_nomsg(sinfo_extract_frames_group_type(wrk_set,
-                                &pro_set,
-                                CPL_FRAME_GROUP_PRODUCT));
-                check_nomsg(cpl_frameset_join(tot_set,pro_set));
+                sinfo_extract_frames_group_type(wrk_set,&pro_set,
+                                CPL_FRAME_GROUP_PRODUCT);
+                cpl_frameset_join(tot_set,pro_set);
                 sinfo_free_frameset(&pro_set);
                 sinfo_free_frameset(&wrk_set);
 
-
             }
-            check_nomsg(sinfo_extract_frames_group_type(tot_set,
-                            &pro_set,
-                            CPL_FRAME_GROUP_PRODUCT));
-            check_nomsg(cpl_frameset_join(*set,pro_set));
+            sinfo_extract_frames_group_type(tot_set,&pro_set,
+                            CPL_FRAME_GROUP_PRODUCT);
+            cpl_frameset_join(*set,pro_set);
             sinfo_free_frameset(&pro_set);
             sinfo_free_frameset(&tot_set);
             sinfo_free_frame(&sky_frm);
         } else if(aj_meth == 1 ) {
 
-
             sinfo_msg("Dummy obj-sky case");
             sinfo_msg("Fake sky is coming from each next object");
 
             if(nobj > 1) {
                 fk->is_fake_sky=1;
-                ck0(sinfo_get_dummy_obj_sky_stacked_and_cubes(obj_set,&(*set),config,
-                                fk,pro_ctg_stack,recipe_id),
-                    "Found error to get obj-sky-stacked frame");
+                sinfo_get_dummy_obj_sky_stacked_and_cubes(obj_set,&(*set),config,
+                                fk,pro_ctg_stack,recipe_id);
 
             } else {
                 sinfo_msg("Only one object frame, no sky");
-                check_nomsg(p=cpl_parameterlist_find(config,
-                                "sinfoni.sinfo_utl_skycor.rot_cor"));
-                check_nomsg(cpl_parameter_set_bool(p,FALSE));
+                p=cpl_parameterlist_find(config,
+                                "sinfoni.sinfo_utl_skycor.rot_cor");
+                cpl_parameter_set_bool(p,FALSE);
 
-                ck0(sinfo_new_stack_frames(config,*set,pro_ctg_stack,0,fk,recipe_id),
-                    "Error stacking frame");
+                sinfo_new_stack_frames(config,*set,pro_ctg_stack,0,fk,recipe_id);
 
                 /* cube generation */
                 sinfo_msg("------------------------------") ;
                 sinfo_msg("BUILDING CUBE %d",i);
                 sinfo_msg("------------------------------") ;
-                ck0(sinfo_new_cubes_build(recipe_id,config,*set,*pro_ctg_cube,i),
-                    "Error GENERATING CUBE %d", i) ;
+                sinfo_new_cubes_build(recipe_id,config,*set,*pro_ctg_cube,i);
 
                 sinfo_msg("------------------------------") ;
                 sinfo_msg("BUILT CUBE %d",i);
@@ -842,52 +807,44 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
             sinfo_msg("------------------------------") ;
             sinfo_msg("staks each OBJECT ");
             sinfo_msg("------------------------------") ;
-            check_nomsg(tot_set=cpl_frameset_new());
+            tot_set=cpl_frameset_new();
 
             for (i=0;i<nobj;i++) {
 
-                check_nomsg(wrk_set=cpl_frameset_new());
-                check_nomsg(obj_frm=cpl_frameset_get_frame(obj_set,i));
-                check_nomsg(dup_frm=cpl_frame_duplicate(obj_frm));
-                check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
+                wrk_set=cpl_frameset_new();
+                obj_frm=cpl_frameset_get_frame(obj_set,i);
+                dup_frm=cpl_frame_duplicate(obj_frm);
+                cpl_frameset_insert(wrk_set,dup_frm);
                 for(k=0;k<ncdb;k++) {
-                    check_nomsg(cdb_frm=cpl_frameset_get_frame(cdb_set,k));
-                    check_nomsg(dup_frm=cpl_frame_duplicate(cdb_frm));
-                    check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
+                    cdb_frm=cpl_frameset_get_frame(cdb_set,k);
+                    dup_frm=cpl_frame_duplicate(cdb_frm);
+                    cpl_frameset_insert(wrk_set,dup_frm);
                 }
 
-
                 snprintf(outname,MAX_NAME_SIZE-1,"%s%d%s","out_stack",i,".fits");
-                ck0(sinfo_new_stack_frames(config,wrk_set,pro_ctg_stack,
-                                i,fk,recipe_id),"Error stacking frame %d",i);
-
+                sinfo_new_stack_frames(config,wrk_set,pro_ctg_stack,
+                                i,fk,recipe_id);
 
                 /* cube generation */
                 sinfo_msg("------------------------------") ;
                 sinfo_msg("BUILDING CUBE %d",i);
                 sinfo_msg("------------------------------") ;
-                ck0( ( ind=sinfo_new_cubes_build(recipe_id,config,wrk_set,
-                                *pro_ctg_cube,i) ),
-                    "Error GENERATING CUBE no. %d\n", ind) ;
+                ind=sinfo_new_cubes_build(recipe_id,config,wrk_set,
+                                *pro_ctg_cube,i);
 
                 sinfo_msg("------------------------------") ;
                 sinfo_msg("BUILT CUBE %d",i);
                 sinfo_msg("------------------------------") ;
-                check_nomsg(sinfo_extract_frames_group_type(wrk_set,
-                                &pro_set,
-                                CPL_FRAME_GROUP_PRODUCT));
-                check_nomsg(cpl_frameset_join(tot_set,pro_set));
+                sinfo_extract_frames_group_type(wrk_set,&pro_set,
+                                CPL_FRAME_GROUP_PRODUCT);
+                cpl_frameset_join(tot_set,pro_set);
                 sinfo_free_frameset(&pro_set);
                 sinfo_free_frameset(&wrk_set);
 
-
             }
-
-
-            check_nomsg(sinfo_extract_frames_group_type(tot_set,
-                            &pro_set,
-                            CPL_FRAME_GROUP_PRODUCT));
-            check_nomsg(cpl_frameset_join(*set,pro_set));
+            sinfo_extract_frames_group_type(tot_set,&pro_set,
+                            CPL_FRAME_GROUP_PRODUCT);
+            cpl_frameset_join(*set,pro_set);
             sinfo_free_frameset(&pro_set);
             sinfo_free_frameset(&tot_set);
 
@@ -908,13 +865,11 @@ int sinfo_cub_stk_frames(cpl_parameterlist* config,
     sinfo_free_frameset(&sky_set);
     sinfo_free_frameset(&cdb_set);
     sinfo_fake_delete(&fk);
+    sinfo_print_rec_status(0);
     return -1;
 
-
 }
 
-
-
 static const char* sinfo_new_set_stk_procatg(const char* tag)
 {
 
@@ -957,78 +912,4 @@ const char* sinfo_new_set_obj_procatg(const char* tag)
 
 }
 
-/*
-static int
-sinfo_get_obj_sky_frm_pair(
-cpl_frameset** obj_set,
-const int i,
-cpl_frame** obj_frm,
-cpl_frame** sky_frm)
-{
-  double mjd_obj=0;
-  double mjd_sky_inf=0;
-  double mjd_sky_sup=0;
-
-
-  double obj_cumx=0;
-  double obj_cumy=0;
-
-  double sky_sup_cumx=0;
-  double sky_sup_cumy=0;
-
-  double sky_inf_cumx=0;
-  double sky_inf_cumy=0;
-  double cum_thres=0.5;
-  int nobj=0;
-  cpl_frame* sky_frm_inf=NULL;
-  cpl_frame* sky_frm_sup=NULL;
-
-  check_nomsg(*obj_frm=cpl_frameset_get_frame(*obj_set,i));
-  mjd_obj    = sinfo_get_mjd_obs(*obj_frm);
-  obj_cumx=sinfo_get_cumoffsetx(*obj_frm);
-  obj_cumy=sinfo_get_cumoffsety(*obj_frm);
-
-  if(i>0) {
-    check_nomsg(sky_frm_inf=cpl_frameset_get_frame(*obj_set,i-1));
-    mjd_sky_inf = sinfo_get_mjd_obs(sky_frm_inf);
-    sky_inf_cumx=sinfo_get_cumoffsetx(sky_frm_inf);
-    sky_inf_cumy=sinfo_get_cumoffsety(sky_frm_inf);
-  }
-
-  if(i<nobj-1) {
-    check_nomsg(sky_frm_sup=cpl_frameset_get_frame(*obj_set,i+1));
-    mjd_sky_sup = sinfo_get_mjd_obs(sky_frm_sup);
-    sky_sup_cumx=sinfo_get_cumoffsetx(sky_frm_sup);
-    sky_sup_cumy=sinfo_get_cumoffsety(sky_frm_sup);
-  }
-
-  if(i==0) {
-    *sky_frm = sky_frm_sup;
-  } else if(i==(nobj-1)) {
-    *sky_frm = sky_frm_inf;
-  } else {
-       if( fabs( mjd_sky_inf - mjd_obj ) <
-           fabs( mjd_sky_sup - mjd_obj ) ) {
-         if((fabs(sky_inf_cumx-obj_cumx) > cum_thres) ||
-            (fabs(sky_inf_cumy-obj_cumy) > cum_thres)) {
-            *sky_frm = sky_frm_inf;
-         } else {
-            *sky_frm = sky_frm_sup;
-         }
-       } else {
-         if((fabs(sky_sup_cumx-obj_cumx) > cum_thres) ||
-            (fabs(sky_sup_cumy-obj_cumy) > cum_thres)) {
-            *sky_frm = sky_frm_sup;
-         } else {
-            *sky_frm = sky_frm_inf;
-         }
-       }
-  }
-  return 0;
-
- cleanup:
-  return -1;
-
-}
- */
 /**@}*/
