@@ -482,7 +482,7 @@ int sinfo_new_lsqfit_c ( float * xdat,
   @param im input image
   @return nothing
  */
-void sinfo_new_convert_ZEROs_to_0_for_images(cpl_image * im)
+static void sinfo_new_convert_ZEROs_to_0_for_images(cpl_image * im)
 {
     int i ;
     int ilx=0;
