@@ -63,7 +63,6 @@
 /*----------------------------------------------------------------------------
  *                        Function ANSI C prototypes
  *--------------------------------------------------------------------------*/
-double sinfo_nev_ille(double x[], double f[], int n, double z, int* flag);
 
 float 
 sinfo_new_f_median(float * array, int n);
@@ -197,34 +196,6 @@ sinfo_new_correlation ( float * data1, float * data2, int ndata ) ;
    @return  nothing
 */
 
-void 
-sinfo_new_convert_ZEROs_to_0_for_images(cpl_image * im) ;
-
-/**
-   @name  sinfo_new_convert_ZEROs_to_0_for_cubes_range()
-   @memo  this function converts any ZEROs in a cube to 0
-   @param input cube
-   @return nothing
-*/
-
-void 
-sinfo_new_convert_ZEROs_to_0_for_cubes_range(cpl_imagelist * cube,
-                                             const int z_min,
-                                             const int z_max);
-
-/**
-   @name  new_convert_0_to_ZEROs_for_cubes()
-   @memo   this function converts any 0 in a cube to ZERO
-   @param cube  input cube
-   @param z_min  min z to be considered
-   @param z_max  max z to be considered
-   @return nothing
-*/
-
-void 
-sinfo_new_convert_0_to_ZERO_for_cubes_range(cpl_imagelist * cube,
-                                            const int z_min,
-                                            const int z_max);
 /**
    @name  sinfo_new_convert_ZEROs_to_0_for_cubes()
    @memo   this function converts any ZEROs in a cube to 0
@@ -256,15 +227,6 @@ sinfo_new_convert_0_to_ZEROs_for_images(cpl_image * im) ;
 void 
 sinfo_new_convert_0_to_ZERO_for_cubes(cpl_imagelist * cube) ;
 
-/**
-   @name  new_invert_image()
-   @memo  this function multiplies each image value by -1.
-   @param im     input image
-   @result inverted input image (overwritten)
-*/
-
-void sinfo_new_invert(cpl_image * im) ;
-
 
 /**
    @name      sinfo_new_xcorrel ()
