@@ -38,9 +38,15 @@ CPL_BEGIN_DECLS
 #define DRS_SETUP_WAVE                     "DRS_SETUP_WAVE"
 #define EXTCOEFF_TABLE                     "EXTCOEFF_TABLE"
 #define FLUX_STD_TABLE                     "FLUX_STD_TABLE"
+#define FLUX_STD_CATALOG                   "FLUX_STD_CATALOG"
+#define TELL_MOD_CATALOG                   "TELL_MOD_CATALOG"
+#define RESP_FIT_POINTS_CAT                "RESP_FIT_POINTS_CATALOG"
 /* catalog of flux of standard stars*/
-#define FLUX_STD_CATALOG		   "FLUX_STD_CATALOG"
-
+#define EFFICIENCY_WINDOWS		           "EFFICIENCY_WINDOWS"
+#define RESPONSE_WINDOWS		           "RESPONSE_WINDOWS"
+#define QUALITY_AREAS		               "QUALITY_AREAS"
+#define FIT_AREAS		                   "FIT_AREAS"
+#define HIGH_ABS_REGIONS		           "HIGH_ABS_REGIONS"
 CPL_END_DECLS
 
 #endif
