@@ -777,7 +777,7 @@ cpl_image * sinfo_new_optimal_extraction_from_cube( cpl_imagelist * cube,
         mpar[i] = 1 ;
     }
 
-    if ( -1 == (fitInd = sinfo_new_fit_2d_gaussian(averagedIm,
+    if ( -1 == sinfo_new_fit_2d_gaussian(averagedIm,
                                                    fit_par,
                                                    derv_par,
                                                    mpar,
@@ -785,7 +785,7 @@ cpl_image * sinfo_new_optimal_extraction_from_cube( cpl_imagelist * cube,
                                                    lly,
                                                    halfbox_x,
                                                    halfbox_y,
-                                                   check2 )) )
+                                                   check2 ) )
     {
         sinfo_msg_warning("sinfo_fit2dGaussian failed!") ;
         cpl_image_delete(retIm) ;
