@@ -87,5 +87,17 @@ sinfo_efficiency_compute(cpl_frame* frm_sci,
                        cpl_frame* frm_cat,
                        cpl_frame* frm_atmext);
 
+cpl_error_code
+sinfo_response_compute(const char* plugin_id, cpl_parameterlist* config,
+		cpl_frameset* ref_set,cpl_frameset* sof);
 
+cpl_error_code
+sinfo_flux_calibrate_spectra(const char* plugin_id,
+		cpl_parameterlist* config, cpl_frameset* ref_set, cpl_frameset* sof);
+
+cpl_error_code
+sinfo_flux_calibrate_cube(const char* procatg, const char* plugin_id,
+		cpl_parameterlist* config, cpl_frameset* ref_set, cpl_frameset* sof);
+int sinfo_can_flux_calibrate(cpl_frameset* sof);
+int sinfo_can_compute_response(cpl_frameset* sof);
 #endif
