@@ -168,11 +168,8 @@ sinfo_coadd_cubes(const int rsx, const int rsy, const int nc,
                   float* offx, float* offy, double* times)
 {
     int onp;
-    int z_stp=8;
-    int z_siz=0;
-    int z_min=0;
-    int z_max=0;
-    int kappa=2;
+
+
     char name[SIZE];
     cpl_image* img_j=NULL;
     cpl_image* img_m=NULL;
@@ -181,11 +178,13 @@ sinfo_coadd_cubes(const int rsx, const int rsy, const int nc,
     onp = cpl_imagelist_get_size(cube_obj[0]);
 
     sinfo_msg_warning("Coadd data");
+    int z_stp=8;
+    int kappa=2;
     for (int z = 0; z < onp; z += z_stp) {
 
-        z_siz = (z_stp < (onp - z)) ? z_stp : (onp - z);
-        z_min = z;
-        z_max = z_min + z_siz;
+        int z_siz = (z_stp < (onp - z)) ? z_stp : (onp - z);
+        int z_min = z;
+        int z_max = z_min + z_siz;
         sinfo_msg("Coadding cubes: range [%4.4d,%4.4d) of 0-%d\n", z_min, z_max,
                         onp);
 
